window.Gleam.initSearch([{"doc":"gleam_community_maths","title":"gleam_community_maths","content":"# gleam-community/maths\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_community_maths)](https://hex.pm/packages/gleam_community_maths)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_community_maths/)\n\nA basic mathematics library that contains some of the most fundamental mathematics functions and utilities.\n\nThe library supports both targets: Erlang and JavaScript.\n\n## Quickstart\n\n```gleam\nimport gleam/float\nimport gleam/list\nimport gleam/yielder\nimport gleam_community/maths\nimport gleeunit/should\n\npub fn example() {\n  // Evaluate the sine function\n  let result = maths.sin(maths.pi())\n  // Set the relative and absolute tolerance\n  let assert Ok(absolute_tol) = float.power(10.0, -6.0)\n  let relative_tol = 0.0\n  // Check that the value is very close to 0.0\n  // That is, if &#39;result&#39; is within +/- 10^(-6)\n  maths.is_close(result, 0.0, relative_tol, absolute_tol)\n  |&gt; should.be_true()\n\n  // Find the greatest common divisor\n  maths.gcd(54, 24)\n  |&gt; should.equal(6)\n\n  // Determine if 999983 is a prime number\n  maths.is_prime(999_983)\n  |&gt; should.equal(True)\n\n  // Find the minimum and maximum of a list\n  maths.extrema([10.0, 3.0, 50.0, 20.0, 3.0], float.compare)\n  |&gt; should.equal(Ok(#(3.0, 50.0)))\n\n  // Determine if a number is fractional\n  maths.is_fractional(0.3333)\n  |&gt; should.equal(True)\n\n  // Generate all k = 2 combinations of [1, 2, 3]\n  let assert Ok(combinations) = maths.list_combination([1, 2, 3], 2)\n  combinations\n  |&gt; yielder.to_list()\n  |&gt; should.equal([[1, 2], [1, 3], [2, 3]])\n\n  // Compute the Cosine Similarity between two (orthogonal) &quot;vectors&quot;\n  maths.cosine_similarity([#(-1.0, 1.0), #(1.0, 1.0), #(0.0, -1.0)])\n  |&gt; should.equal(Ok(0.0))\n\n  // Generate a list of 3 logarithmically-spaced points over a specified \n  // interval, i.e., [10^1, 10^3]\n  let assert Ok(logspace) = maths.logarithmic_space(1.0, 3.0, 3, True, 10.0)\n  let pairs = logspace |&gt; list.zip([10.0, 100.0, 1000.0])\n  pairs\n  |&gt; list.all(fn(x) { x.0 == x.1 })\n  |&gt; should.be_true()\n}\n\n```\n\n## Installation\n\n`gleam_community` packages are published to [hex.pm](https://hex.pm/packages/gleam_community_maths)\nwith the prefix `gleam_community_`. You can add them to your Gleam projects directly:\n\n```sh\ngleam add gleam_community_maths\n```\n","url":"index.html"},{"doc":"gleam_community/maths","title":"absolute_difference","content":"pub fn absolute_difference(a: Float, b: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The absolute difference:\n\n \\\\[\n  \\forall x, y \\in \\mathbb{R}, \\\\; |x - y|  \\in \\mathbb{R}_{+}.\n \\\\]\n\n The function takes two inputs \\\\(x\\\\) and \\\\(y\\\\) and returns a positive float\n value which is the absolute difference of the inputs.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.absolute_difference(-10.0, 10.0)\n       |&gt; should.equal(20.0)\n\n       maths.absolute_difference(0.0, -2.0)\n       |&gt; should.equal(2.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.absolute_difference\ngleam_community/maths absolute_difference","url":"gleam_community/maths.html#absolute_difference"},{"doc":"gleam_community/maths","title":"acos","content":"pub fn acos(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse cosine function:\n\n \\\\[\n \\forall x \\in \\[-1, 1\\],   \\\\; \\cos^{-1}{(x)} = y \\in \\[0, \\pi \\]\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\[-1, 1\\]\\\\) as input and\n returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\[0, \\pi \\]\\\\) (an\n angle in radians). If the input value is outside the domain of the function\n an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.acos(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.acos(1.1)\n       |&gt; should.be_error()\n\n       maths.acos(-1.1)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.acos\ngleam_community/maths acos","url":"gleam_community/maths.html#acos"},{"doc":"gleam_community/maths","title":"acosh","content":"pub fn acosh(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse hyperbolic cosine function:\n\n \\\\[\n \\forall x \\in [1, +\\infty\\),   \\\\; \\cosh^{-1}{(x)} = y \\in \\[0, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\[1, +\\infty\\)\\\\) as input\n and returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\[0, +\\infty\\)\\\\)\n (an angle in radians). If the input value is outside the domain of the function\n an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.acosh(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.acosh(0.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.acosh\ngleam_community/maths acosh","url":"gleam_community/maths.html#acosh"},{"doc":"gleam_community/maths","title":"all_close","content":"pub fn all_close(\n  arr: List(#(Float, Float)),\n  rtol: Float,\n  atol: Float,\n) -&gt; List(Bool)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Determine if each value \\\\(x_i\\\\) is close to or equivalent to its corresponding reference value\n \\\\(y_i\\\\), in a list of value pairs \\\\((x_i, y_i)\\\\), based on supplied relative \\\\(r_{tol}\\\\)\n and absolute  \\\\(a_{tol}\\\\) tolerance values. The equivalence of each pair \\\\((x_i, y_i)\\\\) is\n determined by the equation:\n\n \\\\[\n     \\|x_i - y_i\\| \\leq (a_{tol} + r_{tol} \\cdot \\|y_i\\|), \\\\; \\forall i=1,...,n.\n \\\\]\n\n A list of `Bool` values is returned, where each entry indicates if the corresponding pair\n satisfies the condition. If all conditions are satisfied, the list will contain only `True`\n values.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/list\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let value = 99.0\n       let reference_value = 100.0\n       let xarr = list.repeat(value, 42)\n       let yarr = list.repeat(reference_value, 42)\n       let arr = list.zip(xarr, yarr)\n       // We set &#39;absolute_tolerance&#39; and &#39;relative_tolerance&#39; such that\n       // the values are equivalent if &#39;value&#39; is within 1 percent of\n       // &#39;reference_value&#39; +/- 0.1\n       let relative_tolerance = 0.01\n       let absolute_tolerance = 0.1\n       let assert Ok(result) =\n         maths.all_close(arr, relative_tolerance, absolute_tolerance)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.all_close\ngleam_community/maths all_close","url":"gleam_community/maths.html#all_close"},{"doc":"gleam_community/maths","title":"arg_maximum","content":"pub fn arg_maximum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(List(Int), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the indices of the maximum values in a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/float\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.arg_maximum(float.compare)\n       |&gt; should.be_error()\n\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; maths.arg_maximum(float.compare)\n       |&gt; should.equal(Ok([0, 1]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.arg_maximum\ngleam_community/maths arg_maximum","url":"gleam_community/maths.html#arg_maximum"},{"doc":"gleam_community/maths","title":"arg_minimum","content":"pub fn arg_minimum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(List(Int), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the indices of the minimum values in a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/float\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.arg_minimum(float.compare)\n       |&gt; should.be_error()\n\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; maths.arg_minimum(float.compare)\n       |&gt; should.equal(Ok([4]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.arg_minimum\ngleam_community/maths arg_minimum","url":"gleam_community/maths.html#arg_minimum"},{"doc":"gleam_community/maths","title":"asin","content":"pub fn asin(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse sine function:\n\n \\\\[\n \\forall x \\in \\[-1, 1\\],   \\\\; \\sin^{-1}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\[-1, 1\\]\\\\) as input and returns a numeric\n value \\\\(y\\\\) that lies in the range \\\\(\\[-\\frac{\\pi}{2}, \\frac{\\pi}{2}\\]\\\\) (an angle in\n radians). If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.asin(0.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.asin(1.1)\n       |&gt; should.be_error()\n\n       maths.asin(-1.1)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.asin\ngleam_community/maths asin","url":"gleam_community/maths.html#asin"},{"doc":"gleam_community/maths","title":"asinh","content":"pub fn asinh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse hyperbolic sine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\sinh^{-1}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, +\\infty\\)\\\\)\n as input and returns a numeric value \\\\(y\\\\) that lies in the range\n \\\\(\\(-\\infty, +\\infty\\)\\\\) (an angle in radians).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.asinh(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.asinh\ngleam_community/maths asinh","url":"gleam_community/maths.html#asinh"},{"doc":"gleam_community/maths","title":"atan","content":"pub fn atan(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse tangent function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),  \\\\; \\tan^{-1}{(x)} = y \\in \\[-\\frac{\\pi}{2}, \\frac{\\pi}{2}\\]\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, +\\infty\\)\\\\) as input and\n returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\[-\\frac{\\pi}{2}, \\frac{\\pi}{2}\\]\\\\)\n (an angle in radians).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.atan(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.atan\ngleam_community/maths atan","url":"gleam_community/maths.html#atan"},{"doc":"gleam_community/maths","title":"atan2","content":"pub fn atan2(y: Float, x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse 2-argument tangent function:\n\n \\\\[\n \\text{atan2}(y, x) =\n \\begin{cases}\n  \\tan^{-1}(\\frac y x) &amp;\\text{if } x &gt; 0, \\\\\\\\\n  \\tan^{-1}(\\frac y x) + \\pi &amp;\\text{if } x &lt; 0 \\text{ and } y \\ge 0, \\\\\\\\\n  \\tan^{-1}(\\frac y x) - \\pi &amp;\\text{if } x &lt; 0 \\text{ and } y &lt; 0, \\\\\\\\\n  +\\frac{\\pi}{2} &amp;\\text{if } x = 0 \\text{ and } y &gt; 0, \\\\\\\\\n  -\\frac{\\pi}{2} &amp;\\text{if } x = 0 \\text{ and } y &lt; 0, \\\\\\\\\n  \\text{undefined} &amp;\\text{if } x = 0 \\text{ and } y = 0.\n \\end{cases}\n \\\\]\n\n The function returns the angle in radians from the x-axis to the line containing\n the origin \\\\(\\(0, 0\\)\\\\) and a point given as input with coordinates \\\\(\\(x, y\\)\\\\).\n The numeric value returned by \\\\(\\text{atan2}(y, x)\\\\) is in the range\n \\\\(\\[-\\pi, \\pi\\]\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.atan2(0.0, 0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.atan2\ngleam_community/maths atan2","url":"gleam_community/maths.html#atan2"},{"doc":"gleam_community/maths","title":"atanh","content":"pub fn atanh(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse hyperbolic tangent function:\n\n \\\\[\n \\forall x \\in \\(-1, 1\\),   \\\\; \\tanh^{-1}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-1, 1\\)\\\\) as input and returns\n a numeric value \\\\(y\\\\) that lies in the range \\\\(\\(-\\infty, \\infty\\)\\\\) (an angle in radians).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.atanh(0.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.atanh(1.0)\n       |&gt; should.be_error()\n\n       maths.atanh(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.atanh\ngleam_community/maths atanh","url":"gleam_community/maths.html#atanh"},{"doc":"gleam_community/maths","title":"beta","content":"pub fn beta(x: Float, y: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The beta function over the real numbers:\n\n \\\\[\n \\text{B}(x, y) = \\frac{\\Gamma(x) \\cdot \\Gamma(y)}{\\Gamma(x + y)}\n \\\\]\n\n The beta function is evaluated through the use of the gamma function.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.beta\ngleam_community/maths beta","url":"gleam_community/maths.html#beta"},{"doc":"gleam_community/maths","title":"braycurtis_distance","content":"pub fn braycurtis_distance(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the Bray-Curtis distance between two lists:\n\n \\\\[\n \\frac{\\sum_{i=1}^n  \\left| x_i - y_i \\right|}\n {\\sum_{i=1}^n \\left| x_i + y_i \\right|}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists, and \\\\(x_i, y_i\\\\) are the values\n in the respective input lists indexed by \\\\(i\\\\).\n\n The Bray-Curtis distance is in the range \\\\([0, 1]\\\\) if all entries \\\\(x_i, y_i\\\\) are\n positive.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.braycurtis_distance([])\n       |&gt; should.be_error()\n\n       maths.braycurtis_distance([#(1.0, 3.0), #(2.0, 4.0)])\n       |&gt; should.equal(Ok(0.4))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n\nSynonyms:\ngleam_community/maths.braycurtis_distance\ngleam_community/maths braycurtis_distance","url":"gleam_community/maths.html#braycurtis_distance"},{"doc":"gleam_community/maths","title":"braycurtis_distance_with_weights","content":"pub fn braycurtis_distance_with_weights(\n  arr: List(#(Float, Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted Bray-Curtis distance between two lists:\n\n \\\\[\n \\frac{\\sum_{i=1}^n w_{i} \\left| x_i - y_i \\right|}\n {\\sum_{i=1}^n w_{i}\\left| x_i + y_i \\right|}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists, and \\\\(x_i, y_i\\\\) are the values\n in the respective input lists indexed by \\\\(i\\\\), while the\n \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n The Bray-Curtis distance is in the range \\\\([0, 1]\\\\) if all entries \\\\(x_i, y_i\\\\) are\n positive and \\\\(w_i = 1.0\\\\;\\forall i=1...n\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.braycurtis_distance_with_weights([])\n       |&gt; should.be_error()\n\n       maths.braycurtis_distance_with_weights([#(1.0, 3.0, 0.5), #(2.0, 4.0, 1.0)])\n       |&gt; should.equal(Ok(0.375))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.braycurtis_distance_with_weights\ngleam_community/maths braycurtis_distance_with_weights","url":"gleam_community/maths.html#braycurtis_distance_with_weights"},{"doc":"gleam_community/maths","title":"canberra_distance","content":"pub fn canberra_distance(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the Canberra distance between two lists:\n\n \\\\[\n \\sum_{i=1}^n \\frac{\\left| x_i - y_i \\right|}\n {\\left| x_i \\right| + \\left| y_i \\right|}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists, and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.canberra_distance([])\n       |&gt; should.be_error()\n\n       maths.canberra_distance([#(1.0, -2.0), #(2.0, -1.0)])\n       |&gt; should.equal(Ok(2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.canberra_distance\ngleam_community/maths canberra_distance","url":"gleam_community/maths.html#canberra_distance"},{"doc":"gleam_community/maths","title":"canberra_distance_with_weights","content":"pub fn canberra_distance_with_weights(\n  arr: List(#(Float, Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted Canberra distance between two lists:\n\n \\\\[\n \\sum_{i=1}^n w_{i}\\frac{\\left| x_i - y_i \\right|}\n {\\left| x_i \\right| + \\left| y_i \\right|}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists, and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\), while the\n \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.canberra_distance_with_weights([])\n       |&gt; should.be_error()\n\n       maths.canberra_distance_with_weights([#(1.0, -2.0, 0.5), #(2.0, -1.0, 1.0)])\n       |&gt; should.equal(Ok(1.5))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.canberra_distance_with_weights\ngleam_community/maths canberra_distance_with_weights","url":"gleam_community/maths.html#canberra_distance_with_weights"},{"doc":"gleam_community/maths","title":"cartesian_product","content":"pub fn cartesian_product(\n  xset: Set(a),\n  yset: Set(b),\n) -&gt; Set(#(a, b))\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generate a set containing all combinations of pairs of elements coming from two given sets.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/set\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       set.from_list([])\n       |&gt; maths.cartesian_product(set.from_list([]))\n       |&gt; should.equal(set.from_list([]))\n\n       set.from_list([1.0, 10.0])\n       |&gt; maths.cartesian_product(set.from_list([1.0, 2.0]))\n       |&gt; should.equal(\n         set.from_list([#(1.0, 1.0), #(1.0, 2.0), #(10.0, 1.0), #(10.0, 2.0)]),\n       )\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cartesian_product\ngleam_community/maths cartesian_product","url":"gleam_community/maths.html#cartesian_product"},{"doc":"gleam_community/maths","title":"cartesian_to_polar","content":"pub fn cartesian_to_polar(x: Float, y: Float) -&gt; #(Float, Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Converts Cartesian coordinates \\\\((x, y)\\\\) to polar coordinates \\\\((r, \\theta)\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.cartesian_to_polar(1.0, 0.0)\n       |&gt; should.equal((1.0, 0.0))\n\n       maths.cartesian_to_polar(0.0, 1.0)\n       |&gt; should.equal((1.0, float.pi() /. 2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cartesian_to_polar\ngleam_community/maths cartesian_to_polar","url":"gleam_community/maths.html#cartesian_to_polar"},{"doc":"gleam_community/maths","title":"chebyshev_distance","content":"pub fn chebyshev_distance(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the Chebyshev distance between two lists (representing vectors):\n\n \\\\[\n \\text{max}_{i=1}^n \\left|x_i - y_i \\right|\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.chebyshev_distance([#(-5.0, -1.0), #(-10.0, -12.0), #(-3.0, -3.0)])\n       |&gt; should.equal(Ok(4.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.chebyshev_distance\ngleam_community/maths chebyshev_distance","url":"gleam_community/maths.html#chebyshev_distance"},{"doc":"gleam_community/maths","title":"chebyshev_distance_with_weights","content":"pub fn chebyshev_distance_with_weights(\n  arr: List(#(Float, Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted Chebyshev distance between two lists (representing vectors):\n\n \\\\[\n \\text{max}_{i=1}^n w_i \\left|x_i - y_i \\right|\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\), while the\n \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.chebyshev_distance_with_weights([\n         #(-5.0, -1.0, 0.5),\n         #(-10.0, -12.0, 1.0),\n         #(-3.0, -3.0, 1.0),\n       ])\n       |&gt; should.equal(Ok(2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.chebyshev_distance_with_weights\ngleam_community/maths chebyshev_distance_with_weights","url":"gleam_community/maths.html#chebyshev_distance_with_weights"},{"doc":"gleam_community/maths","title":"combination","content":"pub fn combination(n: Int, k: Int) -&gt; Result(Int, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the number of \\\\(k\\\\)-combinations of \\\\(n\\\\) elements\n without repetitions:\n\n \\\\[\n C(n, k) = \\binom{n}{k} = \\frac{n!}{k! (n-k)!}\n \\\\]\n\n Also known as &quot;\\\\(n\\\\) choose \\\\(k\\\\)&quot; or the binomial coefficient.\n\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n A \\\\(k\\\\)-combination without repetition is a sequence of \\\\(k\\\\) elements selected from\n \\\\(n\\\\) elements where the order of selection does not matter and elements are not allowed to\n repeat. For example, consider selecting  2 elements from a list of 3 elements:\n `[&quot;A&quot;, &quot;B&quot;, &quot;C&quot;]`. In this case, possible selections are:\n   - `[&quot;A&quot;, &quot;B&quot;]`\n   - `[&quot;A&quot;, &quot;C&quot;]`\n   - `[&quot;B&quot;, &quot;C&quot;]`\n\n &lt;/details&gt;\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.combination(-1, 1)\n       |&gt; should.be_error()\n\n       maths.combination(4, 0)\n       |&gt; should.equal(Ok(1))\n\n       maths.combination(4, 4)\n       |&gt; should.equal(Ok(1))\n\n       maths.combination(13, 5)\n       |&gt; should.equal(Ok(1287))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.combination\ngleam_community/maths combination","url":"gleam_community/maths.html#combination"},{"doc":"gleam_community/maths","title":"combination_with_repetitions","content":"pub fn combination_with_repetitions(\n  n: Int,\n  k: Int,\n) -&gt; Result(Int, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the number of \\\\(k\\\\)-combinations of \\\\(n\\\\) elements\n with repetitions:\n\n \\\\[\n C^*(n, k) = \\binom{n + k - 1}{k} = \\frac{(n + k - 1)!}{k! (n - 1)!}\n \\\\]\n\n Also known as the &quot;stars and bars&quot; problem in maths. Furthermore, the implementation uses an\n efficient iterative multiplicative formula for computing the result.\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n A \\\\(k\\\\)-combination with repetitions is a sequence of \\\\(k\\\\) elements selected from\n \\\\(n\\\\) elements where the order of selection does not matter and elements are allowed to\n repeat. For example, consider selecting 2 elements from a list of 3 elements: `[&quot;A&quot;, &quot;B&quot;, &quot;C&quot;]`.\n In this case, possible selections are:\n   - `[&quot;A&quot;, &quot;A&quot;], [&quot;A&quot;, &quot;B&quot;], [&quot;A&quot;, &quot;C&quot;]`\n   - `[&quot;B&quot;, &quot;B&quot;], [&quot;B&quot;, &quot;C&quot;], [&quot;C&quot;, &quot;C&quot;]`\n\n &lt;/details&gt;\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.combination_with_repetitions(-1, 1)\n       |&gt; should.be_error()\n\n       maths.combination_with_repetitions(2, 3)\n       |&gt; should.equal(Ok(4))\n\n       maths.combination_with_repetitions(13, 5)\n       |&gt; should.equal(Ok(6188))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.combination_with_repetitions\ngleam_community/maths combination_with_repetitions","url":"gleam_community/maths.html#combination_with_repetitions"},{"doc":"gleam_community/maths","title":"copy_sign","content":"pub fn copy_sign(x: Float, y: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes two arguments \\\\(x, y \\in \\mathbb{R}\\\\) and returns \\\\(x\\\\)\n such that it has the same sign as \\\\(y\\\\).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.copy_sign\ngleam_community/maths copy_sign","url":"gleam_community/maths.html#copy_sign"},{"doc":"gleam_community/maths","title":"correlation","content":"pub fn correlation(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate Pearson&#39;s sample correlation coefficient to determine the linear\n relationship between the elements in two lists of equal\n length. The correlation coefficient \\\\(r_{xy} \\in \\[-1, 1\\]\\\\) is calculated\n as:\n\n \\\\[\n r_{xy} =\\frac{\\sum ^n _{i=1}(x_i - \\bar{x})(y_i - \\bar{y})}{\\sqrt{\\sum^n _{i=1}(x_i - \\bar{x})^2} \\sqrt{\\sum^n _{i=1}(y_i - \\bar{y})^2}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the sample size (the length of the input lists),\n \\\\(x_i\\\\), \\\\(y_i\\\\) are the corresponding sample points indexed by \\\\(i\\\\) and\n \\\\(\\bar{x}\\\\), \\\\(\\bar{y}\\\\) are the sample means.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty lists returns an error\n       maths.correlation([], [])\n       |&gt; should.be_error()\n\n       // Perfect positive correlation\n       let xarr =\n         list.range(0, 100)\n         |&gt; list.map(fn(x) { int.to_float(x) })\n       let yarr =\n         list.range(0, 100)\n         |&gt; list.map(fn(y) { int.to_float(y) })\n       list.zip(xarr, yarr)\n       |&gt; maths.correlation()\n       |&gt; should.equal(Ok(1.0))\n\n       // Perfect negative correlation\n       let xarr =\n         list.range(0, 100)\n         |&gt; list.map(fn(x) { -1.0 *. int.to_float(x) })\n       let yarr =\n         list.range(0, 100)\n         |&gt; list.map(fn(y) { int.to_float(y) })\n       list.zip(xarr, yarr)\n       |&gt; maths.correlation()\n       |&gt; should.equal(Ok(-1.0))\n\n       // No correlation (independent variables)\n       let xarr = [1.0, 2.0, 3.0, 4.0]\n       let yarr = [5.0, 5.0, 5.0, 5.0]\n       list.zip(xarr, yarr)\n       |&gt; maths.correlation()\n       |&gt; should.equal(Ok(0.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.correlation\ngleam_community/maths correlation","url":"gleam_community/maths.html#correlation"},{"doc":"gleam_community/maths","title":"cos","content":"pub fn cos(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The cosine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\cos{(x)} = y \\in \\[-1, 1\\]\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, \\infty\\)\\\\) (an angle in\n radians) as input and returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\[-1, 1\\]\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.cos(0.0)\n       |&gt; should.equal(1.0)\n\n       maths.cos(maths.pi())\n       |&gt; should.equal(-1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cos\ngleam_community/maths cos","url":"gleam_community/maths.html#cos"},{"doc":"gleam_community/maths","title":"cosh","content":"pub fn cosh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The hyperbolic cosine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\cosh{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, \\infty\\)\\\\) as input (an angle\n in radians) and returns a numeric value \\\\(y\\\\) that lies in the range\n \\\\(\\(-\\infty, \\infty\\)\\\\). If the input value is too large an overflow error might occur.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.cosh(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cosh\ngleam_community/maths cosh","url":"gleam_community/maths.html#cosh"},{"doc":"gleam_community/maths","title":"cosine_similarity","content":"pub fn cosine_similarity(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the cosine similarity between two lists (representing\n vectors):\n\n \\\\[\n \\frac{\\sum_{i=1}^n  x_i \\cdot y_i}\n {\\left(\\sum_{i=1}^n x_i^2\\right)^{\\frac{1}{2}}\n \\cdot\n \\left(\\sum_{i=1}^n y_i^2\\right)^{\\frac{1}{2}}}\n \\\\; \\in \\\\; \\left[-1, 1\\right]\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i\\\\), \\\\(y_i\\\\) are\n the values in the respective input lists indexed by \\\\(i\\\\).\n\n The cosine similarity provides a value between -1 and 1, where 1 means the\n vectors are in the same direction, -1 means they are in exactly opposite\n directions, and 0 indicates orthogonality.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/option\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       // Two orthogonal vectors\n       maths.cosine_similarity([#(-1.0, 1.0), #(1.0, 1.0), #(0.0, -1.0)])\n       |&gt; should.equal(Ok(0.0))\n\n       // Two identical (parallel) vectors\n       maths.cosine_similarity([#(1.0, 1.0), #(2.0, 2.0), #(3.0, 3.0)])\n       |&gt; should.equal(Ok(1.0))\n\n       // Two parallel, but oppositely oriented vectors\n       maths.cosine_similarity([#(-1.0, 1.0), #(-2.0, 2.0), #(-3.0, 3.0)])\n       |&gt; should.equal(Ok(-1.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cosine_similarity\ngleam_community/maths cosine_similarity","url":"gleam_community/maths.html#cosine_similarity"},{"doc":"gleam_community/maths","title":"cosine_similarity_with_weights","content":"pub fn cosine_similarity_with_weights(\n  arr: List(#(Float, Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted cosine similarity between two lists (representing\n vectors):\n\n \\\\[\n \\frac{\\sum_{i=1}^n w_{i} \\cdot x_i \\cdot y_i}\n {\\left(\\sum_{i=1}^n w_{i} \\cdot x_i^2\\right)^{\\frac{1}{2}}\n \\cdot\n \\left(\\sum_{i=1}^n w_{i} \\cdot y_i^2\\right)^{\\frac{1}{2}}}\n \\\\; \\in \\\\; \\left[-1, 1\\right]\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i\\\\), \\\\(y_i\\\\) are\n the values in the respective input lists indexed by \\\\(i\\\\), while the\n \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n The cosine similarity provides a value between -1 and 1, where 1 means the\n vectors are in the same direction, -1 means they are in exactly opposite\n directions, and 0 indicates orthogonality.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/option\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n\n       let assert Ok(result) =\n         maths.cosine_similarity_with_weights([\n           #(1.0, 1.0, 2.0),\n           #(2.0, 2.0, 3.0),\n           #(3.0, 3.0, 4.0),\n         ])\n       result\n       |&gt; maths.is_close(1.0, 0.0, tolerance)\n       |&gt; should.be_true()\n\n       let assert Ok(result) =\n         maths.cosine_similarity_with_weights([\n           #(-1.0, 1.0, 1.0),\n           #(-2.0, 2.0, 0.5),\n           #(-3.0, 3.0, 0.33),\n         ])\n       result\n       |&gt; maths.is_close(-1.0, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cosine_similarity_with_weights\ngleam_community/maths cosine_similarity_with_weights","url":"gleam_community/maths.html#cosine_similarity_with_weights"},{"doc":"gleam_community/maths","title":"cumulative_product","content":"pub fn cumulative_product(arr: List(Float)) -&gt; List(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the cumulative product of the elements in a list:\n\n \\\\[\n v_j = \\prod_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, \\\\(v_j\\\\) is the \\\\(j\\\\)&#39;th element in the cumulative product\n of \\\\(n\\\\) elements. That is, \\\\(n\\\\) is the length of the list and\n \\\\(x_i \\in \\mathbb{R}\\\\) is the value in the input list indexed by \\\\(i\\\\).\n The value \\\\(v_j\\\\) is thus the sum of the \\\\(1\\\\) to \\\\(j\\\\) first elements\n in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.cumulative_product()\n       |&gt; should.equal([])\n\n       [1.0, 2.0, 3.0]\n       |&gt; maths.cumulative_product()\n       |&gt; should.equal([1.0, 2.0, 6.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cumulative_product\ngleam_community/maths cumulative_product","url":"gleam_community/maths.html#cumulative_product"},{"doc":"gleam_community/maths","title":"cumulative_sum","content":"pub fn cumulative_sum(arr: List(Float)) -&gt; List(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the cumulative sum of the elements in a list:\n\n \\\\[\n v_j = \\sum_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, \\\\(v_j\\\\) is the \\\\(j\\\\)&#39;th element in the cumulative sum of \\\\(n\\\\)\n elements. That is, \\\\(n\\\\) is the length of the list and \\\\(x_i \\in \\mathbb{R}\\\\)\n is the value in the input list indexed by \\\\(i\\\\). The value \\\\(v_j\\\\) is thus the\n sum of the \\\\(1\\\\) to \\\\(j\\\\) first elements in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.cumulative_sum()\n       |&gt; should.equal([])\n\n       [1.0, 2.0, 3.0]\n       |&gt; maths.cumulative_sum()\n       |&gt; should.equal([1.0, 3.0, 6.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.cumulative_sum\ngleam_community/maths cumulative_sum","url":"gleam_community/maths.html#cumulative_sum"},{"doc":"gleam_community/maths","title":"degrees_to_radians","content":"pub fn degrees_to_radians(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Convert a value in degrees to a value measured in radians.\n That is, \\\\(1 \\text{ degrees } = \\frac{\\pi}{180} \\text{ radians }\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.degrees_to_radians(360.)\n       |&gt; should.equal(2. *. maths.pi())\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.degrees_to_radians\ngleam_community/maths degrees_to_radians","url":"gleam_community/maths.html#degrees_to_radians"},{"doc":"gleam_community/maths","title":"divisors","content":"pub fn divisors(n: Int) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns all the positive divisors of an integer, including the\n number itself.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.divisors(4)\n       |&gt; should.equal([1, 2, 4])\n\n       maths.divisors(6)\n       |&gt; should.equal([1, 2, 3, 6])\n\n       maths.divisors(13)\n       |&gt; should.equal([1, 13])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.divisors\ngleam_community/maths divisors","url":"gleam_community/maths.html#divisors"},{"doc":"gleam_community/maths","title":"e","content":"pub fn e() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Euler&#39;s number \\\\(e \\approx 2.71828\\dots\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n\n       // Test that the constant is approximately equal to 2.7128...\n       maths.e()\n       |&gt; maths.is_close(2.7182818284590452353602, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.e\ngleam_community/maths e","url":"gleam_community/maths.html#e"},{"doc":"gleam_community/maths","title":"erf","content":"pub fn erf(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The error function.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.erf\ngleam_community/maths erf","url":"gleam_community/maths.html#erf"},{"doc":"gleam_community/maths","title":"euclidean_distance","content":"pub fn euclidean_distance(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the Euclidean distance between two lists (representing\n vectors):\n\n \\\\[\n \\left( \\sum_{i=1}^n \\left|x_i - y_i \\right|^{2} \\right)^{\\frac{1}{2}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n\n       let assert Ok(result) = maths.euclidean_distance([#(1.0, 2.0), #(3.0, 4.0)])\n       result\n       |&gt; maths.is_close(1.4142135623730951, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.euclidean_distance\ngleam_community/maths euclidean_distance","url":"gleam_community/maths.html#euclidean_distance"},{"doc":"gleam_community/maths","title":"euclidean_distance_with_weights","content":"pub fn euclidean_distance_with_weights(\n  arr: List(#(Float, Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted Euclidean distance between two lists (representing\n vectors):\n\n \\\\[\n \\left( \\sum_{i=1}^n w_{i} \\left|x_i - y_i \\right|^{2} \\right)^{\\frac{1}{2}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\), while the\n \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n\n       let assert Ok(result) =\n         maths.euclidean_distance_with_weights([#(1.0, 2.0, 0.5), #(3.0, 4.0, 1.0)])\n       result\n       |&gt; maths.is_close(1.224744871391589, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.euclidean_distance_with_weights\ngleam_community/maths euclidean_distance_with_weights","url":"gleam_community/maths.html#euclidean_distance_with_weights"},{"doc":"gleam_community/maths","title":"euclidean_modulo","content":"pub fn euclidean_modulo(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n\n Given two integers, \\\\(x\\\\) (dividend) and \\\\(y\\\\) (divisor), the Euclidean modulo\n of \\\\(x\\\\) by \\\\(y\\\\), denoted as \\\\(x \\mod y\\\\), is the remainder \\\\(r\\\\) of the\n division of \\\\(x\\\\) by \\\\(y\\\\), such that:\n\n \\\\[\n x = q \\cdot y + r \\quad \\text{and} \\quad 0 \\leq r &lt; |y|,\n \\\\]\n\n where \\\\(q\\\\) is an integer that represents the quotient of the division.\n\n Note that like the Gleam division operator `/` this will return `0` if one of\n the arguments is `0`.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.euclidean_modulo(15, 4)\n       |&gt; should.equal(3)\n\n       maths.euclidean_modulo(-3, -2)\n       |&gt; should.equal(1)\n\n       maths.euclidean_modulo(5, 0)\n       |&gt; should.equal(0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.euclidean_modulo\ngleam_community/maths euclidean_modulo","url":"gleam_community/maths.html#euclidean_modulo"},{"doc":"gleam_community/maths","title":"exponential","content":"pub fn exponential(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The exponential function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; e^{x} = y \\in \\(0, +\\infty\\)\n \\\\]\n\n where \\\\(e \\approx 2.71828\\dots\\\\) is Eulers&#39; number.\n\n Note: If the input value \\\\(x\\\\) is too large an overflow error might occur.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.exponential(0.0)\n       |&gt; should.equal(1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.exponential\ngleam_community/maths exponential","url":"gleam_community/maths.html#exponential"},{"doc":"gleam_community/maths","title":"extrema","content":"pub fn extrema(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(#(a, a), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns a tuple consisting of the minimum and maximum values of a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/float\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.extrema(float.compare)\n       |&gt; should.be_error()\n\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; maths.extrema(float.compare)\n       |&gt; should.equal(Ok(#(1.0, 4.0)))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.extrema\ngleam_community/maths extrema","url":"gleam_community/maths.html#extrema"},{"doc":"gleam_community/maths","title":"factorial","content":"pub fn factorial(n: Int) -&gt; Result(Int, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the total number of combinations of \\\\(n\\\\)\n elements, that is \\\\(n!\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.factorial(-1)\n       |&gt; should.be_error()\n\n       maths.factorial(0)\n       |&gt; should.equal(Ok(1))\n\n       maths.factorial(3)\n       |&gt; should.equal(Ok(6))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.factorial\ngleam_community/maths factorial","url":"gleam_community/maths.html#factorial"},{"doc":"gleam_community/maths","title":"flip_sign","content":"pub fn flip_sign(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function flips the sign of a given input value \\\\(x \\in \\mathbb{R}\\\\).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.flip_sign\ngleam_community/maths flip_sign","url":"gleam_community/maths.html#flip_sign"},{"doc":"gleam_community/maths","title":"gamma","content":"pub fn gamma(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The gamma function over the real numbers. The function is essentially equal to\n the factorial for any positive integer argument: \\\\(\\Gamma(n) = (n - 1)!\\\\)\n\n The implemented gamma function is approximated through Lanczos approximation\n using the same coefficients used by the GNU Scientific Library.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.gamma\ngleam_community/maths gamma","url":"gleam_community/maths.html#gamma"},{"doc":"gleam_community/maths","title":"gcd","content":"pub fn gcd(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function calculates the greatest common divisor of two integers\n \\\\(x, y \\in \\mathbb{Z}\\\\). The greatest common divisor is the largest positive\n integer that is divisible by both \\\\(x\\\\) and \\\\(y\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.gcd(1, 1)\n       |&gt; should.equal(1)\n\n       maths.gcd(100, 10)\n       |&gt; should.equal(10)\n\n       maths.gcd(-36, -17)\n       |&gt; should.equal(1)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.gcd\ngleam_community/maths gcd","url":"gleam_community/maths.html#gcd"},{"doc":"gleam_community/maths","title":"geometric_mean","content":"pub fn geometric_mean(arr: List(Float)) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the geometric mean \\\\(\\bar{x}\\\\) of the elements in a list:\n\n \\\\[\n   \\bar{x} = \\left(\\prod^{n}_{i=1} x_i\\right)^{\\frac{1}{n}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the sample size (the length of the list) and\n \\\\(x_i\\\\) is the sample point in the input list indexed by \\\\(i\\\\).\n Note: The geometric mean is only defined for positive numbers.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.geometric_mean()\n       |&gt; should.be_error()\n\n       // List with negative numbers returns an error\n       [-1.0, -3.0, -6.0]\n       |&gt; maths.geometric_mean()\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       [1.0, 3.0, 9.0]\n       |&gt; maths.geometric_mean()\n       |&gt; should.equal(Ok(3.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.geometric_mean\ngleam_community/maths geometric_mean","url":"gleam_community/maths.html#geometric_mean"},{"doc":"gleam_community/maths","title":"geometric_space","content":"pub fn geometric_space(\n  start: Float,\n  stop: Float,\n  steps: Int,\n  endpoint: Bool,\n) -&gt; Result(List(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns a list of a geometric progression between two specified\n values, where each value is a constant multiple of the previous one. Unlike\n [`logarithmic_space`](#logarithmic_space), this function allows specifying the starting\n and ending values (`start` and `stop`) directly, without requiring them to be transformed\n into exponents.\n\n Internally, the function computes the logarithms of `start` and `stop` and generates evenly\n spaced points in the logarithmic domain (using base 10). These points are then transformed back\n into their original scale to create a sequence of values that grow multiplicatively.\n\n The `start` and `stop` values must be positive, as logarithms are undefined for non-positive\n values. The number of points (`steps`) must also be positive; specifying zero or a negative\n value will result in an error.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n       let assert Ok(logspace) = maths.geometric_space(10.0, 1000.0, 3, True)\n       let pairs = logspace |&gt; list.zip([10.0, 100.0, 1000.0])\n       let assert Ok(result) = maths.all_close(pairs, 0.0, tolerance)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n\n       // Input (start and stop can&#39;t be less than or equal to 0.0)\n       maths.geometric_space(0.0, 1000.0, 3, False)\n       |&gt; should.be_error()\n\n       maths.geometric_space(-1000.0, 0.0, 3, False)\n       |&gt; should.be_error()\n\n       // A negative number of points (-3) does not work\n       maths.geometric_space(10.0, 1000.0, -3, False)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.geometric_space\ngleam_community/maths geometric_space","url":"gleam_community/maths.html#geometric_space"},{"doc":"gleam_community/maths","title":"golden_ratio","content":"pub fn golden_ratio() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The golden ratio: \\\\(\\phi = \\frac{1 + \\sqrt{5}}{2}\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.golden_ratio()\n       |&gt; should.equal(1.618033988749895)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.golden_ratio\ngleam_community/maths golden_ratio","url":"gleam_community/maths.html#golden_ratio"},{"doc":"gleam_community/maths","title":"harmonic_mean","content":"pub fn harmonic_mean(arr: List(Float)) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the harmonic mean \\\\(\\bar{x}\\\\) of the elements in a list:\n\n \\\\[\n   \\bar{x} = \\frac{n}{\\sum_{i=1}^{n}\\frac{1}{x_i}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the sample size (the length of the list) and\n \\\\(x_i\\\\) is the sample point in the input list indexed by \\\\(i\\\\).\n Note: The harmonic mean is only defined for positive numbers.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.harmonic_mean()\n       |&gt; should.be_error()\n\n       // List with negative numbers returns an error\n       [-1.0, -3.0, -6.0]\n       |&gt; maths.harmonic_mean()\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       [1.0, 3.0, 6.0]\n       |&gt; maths.harmonic_mean()\n       |&gt; should.equal(Ok(2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.harmonic_mean\ngleam_community/maths harmonic_mean","url":"gleam_community/maths.html#harmonic_mean"},{"doc":"gleam_community/maths","title":"incomplete_gamma","content":"pub fn incomplete_gamma(a: Float, x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The lower incomplete gamma function over the real numbers.\n\n The implemented incomplete gamma function is evaluated through a power series\n expansion.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.incomplete_gamma\ngleam_community/maths incomplete_gamma","url":"gleam_community/maths.html#incomplete_gamma"},{"doc":"gleam_community/maths","title":"int_absolute_difference","content":"pub fn int_absolute_difference(a: Int, b: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The absolute difference:\n\n \\\\[\n  \\forall x, y \\in \\mathbb{Z}, \\\\; |x - y|  \\in \\mathbb{Z}_{+}.\n \\\\]\n\n The function takes two inputs \\\\(x\\\\) and \\\\(y\\\\) and returns a positive integer\n value which is the absolute difference of the inputs.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.absolute_difference(-10, 10)\n       |&gt; should.equal(20)\n\n       maths.absolute_difference(0, -2)\n       |&gt; should.equal(2)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.int_absolute_difference\ngleam_community/maths int_absolute_difference","url":"gleam_community/maths.html#int_absolute_difference"},{"doc":"gleam_community/maths","title":"int_copy_sign","content":"pub fn int_copy_sign(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes two arguments \\\\(x, y \\in \\mathbb{Z}\\\\) and returns \\\\(x\\\\)\n such that it has the same sign as \\\\(y\\\\).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.int_copy_sign\ngleam_community/maths int_copy_sign","url":"gleam_community/maths.html#int_copy_sign"},{"doc":"gleam_community/maths","title":"int_cumulative_product","content":"pub fn int_cumulative_product(arr: List(Int)) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the cumulative product of the elements in a list:\n\n \\\\[\n v_j = \\prod_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, \\\\(v_j\\\\) is the \\\\(j\\\\)&#39;th element in the cumulative product\n of \\\\(n\\\\) elements. That is, \\\\(n\\\\) is the length of the list and\n \\\\(x_i \\in \\mathbb{Z}\\\\) is the value in the input list indexed by \\\\(i\\\\).\n The value \\\\(v_j\\\\) is thus the product of the \\\\(1\\\\) to \\\\(j\\\\) first elements\n in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.int_cumulative_product()\n       |&gt; should.equal([])\n\n       [1, 2, 3]\n       |&gt; maths.int_cumulative_product()\n       |&gt; should.equal([1, 2, 6])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.int_cumulative_product\ngleam_community/maths int_cumulative_product","url":"gleam_community/maths.html#int_cumulative_product"},{"doc":"gleam_community/maths","title":"int_cumulative_sum","content":"pub fn int_cumulative_sum(arr: List(Int)) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the cumulative sum of the elements in a list:\n\n \\\\[\n v_j = \\sum_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, \\\\(v_j\\\\) is the \\\\(j\\\\)&#39;th element in the cumulative sum of \\\\(n\\\\)\n elements. That is, \\\\(n\\\\) is the length of the list and \\\\(x_i \\in \\mathbb{Z}\\\\)\n is the value in the input list indexed by \\\\(i\\\\). The value \\\\(v_j\\\\) is thus the\n sum of the \\\\(1\\\\) to \\\\(j\\\\) first elements in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.int_cumulative_sum()\n       |&gt; should.equal([])\n\n       [1, 2, 3]\n       |&gt; maths.int_cumulative_sum()\n       |&gt; should.equal([1, 3, 6])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.int_cumulative_sum\ngleam_community/maths int_cumulative_sum","url":"gleam_community/maths.html#int_cumulative_sum"},{"doc":"gleam_community/maths","title":"int_flip_sign","content":"pub fn int_flip_sign(x: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function flips the sign of a given input value \\\\(x \\in \\mathbb{Z}\\\\).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.int_flip_sign\ngleam_community/maths int_flip_sign","url":"gleam_community/maths.html#int_flip_sign"},{"doc":"gleam_community/maths","title":"int_sign","content":"pub fn int_sign(x: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes an input \\\\(x \\in \\mathbb{Z}\\\\) and returns the sign of\n the input, indicating whether it is positive (+1), negative (-1), or zero\n (0).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.int_sign\ngleam_community/maths int_sign","url":"gleam_community/maths.html#int_sign"},{"doc":"gleam_community/maths","title":"interquartile_range","content":"pub fn interquartile_range(\n  arr: List(Float),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the interquartile range (IQR) of the elements in a list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.interquartile_range()\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       [1.0, 2.0, 3.0, 4.0, 5.0]\n       |&gt; maths.interquartile_range()\n       |&gt; should.equal(Ok(3.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.interquartile_range\ngleam_community/maths interquartile_range","url":"gleam_community/maths.html#interquartile_range"},{"doc":"gleam_community/maths","title":"is_between","content":"pub fn is_between(x: Float, lower: Float, upper: Float) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given real number \\\\(x \\in \\mathbb{R}\\\\) is strictly\n between two other real numbers, \\\\(a,b \\in \\mathbb{R}\\\\), such that \\\\(a &lt; x &lt; b\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.is_between(5.5, 5.0, 6.0)\n       |&gt; should.equal(True)\n\n       maths.is_between(5.0, 5.0, 6.0)\n       |&gt; should.equal(False)\n\n       maths.is_between(6.0, 5.0, 6.0)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_between\ngleam_community/maths is_between","url":"gleam_community/maths.html#is_between"},{"doc":"gleam_community/maths","title":"is_close","content":"pub fn is_close(\n  x: Float,\n  y: Float,\n  rtol: Float,\n  atol: Float,\n) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Determine if a given value \\\\(x\\\\) is close to or equivalent to a reference value\n \\\\(y\\\\) based on supplied relative \\\\(r_{tol}\\\\) and absolute \\\\(a_{tol}\\\\) tolerance\n values. The equivalance of the two given values are then determined based on\n the equation:\n\n \\\\[\n     \\|x - y\\| \\leq (a_{tol} + r_{tol} \\cdot \\|y\\|)\n \\\\]\n\n `True` is returned if the statement holds, otherwise `False` is returned.\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let value = 99.\n       let reference_value = 100.\n       // We set &#39;absolute_tolerance&#39; and &#39;relative_tolerance&#39; such that the values are\n       // equivalent if &#39;value&#39; is within 1 percent of &#39;reference_value&#39; +/- 0.1\n       let relative_tolerance = 0.01\n       let absolute_tolerance = 0.10\n       maths.is_close(value, reference_value, relative_tolerance, absolute_tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_close\ngleam_community/maths is_close","url":"gleam_community/maths.html#is_close"},{"doc":"gleam_community/maths","title":"is_divisible","content":"pub fn is_divisible(n: Int, d: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer \\\\(n \\in \\mathbb{Z}\\\\) is divisible by another\n integer \\\\(d \\in \\mathbb{Z}\\\\), such that \\\\(n \\mod d = 0\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example:\n   - \\\\(n = 10\\\\) is divisible by \\\\(d = 2\\\\) because \\\\(10 \\mod 2 = 0\\\\).\n   - \\\\(n = 7\\\\) is not divisible by \\\\(d = 3\\\\) because \\\\(7 \\mod 3 \\neq 0\\\\).\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.is_divisible(10, 2)\n       |&gt; should.equal(True)\n\n       maths.is_divisible(7, 3)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_divisible\ngleam_community/maths is_divisible","url":"gleam_community/maths.html#is_divisible"},{"doc":"gleam_community/maths","title":"is_fractional","content":"pub fn is_fractional(x: Float) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Determine if a given value \\\\(x\\\\) is fractional, i.e., if it contains a fractional part:\n\n \\\\[\n     x - \\lfloor x \\rfloor &gt; 0\n \\\\]\n\n `True` is returned if the given value is fractional (i.e., it has a non-zero decimal part),\n otherwise `False` is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.is_fractional(0.3333)\n       |&gt; should.equal(True)\n\n       maths.is_fractional(1.0)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_fractional\ngleam_community/maths is_fractional","url":"gleam_community/maths.html#is_fractional"},{"doc":"gleam_community/maths","title":"is_multiple","content":"pub fn is_multiple(m: Int, k: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer \\\\(m \\in \\mathbb{Z}\\\\) is a multiple of another\n integer \\\\(k \\in \\mathbb{Z}\\\\), such that \\\\(m = k \\cdot q\\\\), with \\\\(q \\in \\mathbb{Z}\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example:\n   - \\\\(m = 15\\\\) is a multiple of \\\\(k = 5\\\\) because \\\\(15 = 5 \\cdot 3\\\\).\n   - \\\\(m = 14\\\\) is not a multiple of \\\\(k = 5\\\\) because \\\\(\\frac{14}{5}\\\\) does not yield an\n     integer quotient.\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.is_multiple(15, 5)\n       |&gt; should.equal(True)\n\n       maths.is_multiple(14, 5)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_multiple\ngleam_community/maths is_multiple","url":"gleam_community/maths.html#is_multiple"},{"doc":"gleam_community/maths","title":"is_perfect","content":"pub fn is_perfect(n: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer value \\\\(n \\in \\mathbb{Z}\\\\) is a\n perfect number. A number is perfect if it is equal to the sum of its proper\n positive divisors.\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example:\n   - \\\\(6\\\\) is a perfect number since the divisors of 6 are \\\\(1 + 2 + 3 = 6\\\\).\n   - \\\\(28\\\\) is a perfect number since the divisors of 28 are \\\\(1 + 2 + 4 + 7 + 14 = 28\\\\).\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.is_perfect(6)\n       |&gt; should.equal(True)\n\n       maths.is_perfect(28)\n       |&gt; should.equal(True)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_perfect\ngleam_community/maths is_perfect","url":"gleam_community/maths.html#is_perfect"},{"doc":"gleam_community/maths","title":"is_power","content":"pub fn is_power(x: Int, y: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that determines if a given integer value \\\\(x \\in \\mathbb{Z}\\\\) is a power of\n another integer value \\\\(y \\in \\mathbb{Z}\\\\), i.e., the function evaluates whether \\\\(x\\\\) can\n be expressed as \\\\(y^n\\\\) for some integer \\\\(n \\geq 0\\\\), by computing the base-\\\\(y\\\\)\n logarithm of \\\\(x\\\\):\n\n \\\\[\n     n = \\log_y(x)\n \\\\]\n\n If \\\\(n\\\\) is an integer (i.e., it has no fractional part), then \\\\(x\\\\) is a power of \\\\(y\\\\)\n and `True` is returned. Otherwise `False` is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       // Check if 4 is a power of 2 (it is)\n       maths.is_power(4, 2)\n       |&gt; should.equal(True)\n\n       // Check if 5 is a power of 2 (it is not)\n       maths.is_power(5, 2)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_power\ngleam_community/maths is_power","url":"gleam_community/maths.html#is_power"},{"doc":"gleam_community/maths","title":"is_prime","content":"pub fn is_prime(x: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer value \\\\(x \\in \\mathbb{Z}\\\\) is a\n prime number. A prime number is a natural number greater than 1 that has no\n positive divisors other than 1 and itself.\n\n The function uses the Miller-Rabin primality test to assess if \\\\(x\\\\) is prime.\n It is a probabilistic test, so it can mistakenly identify a composite number\n as prime. However, the probability of such errors decreases with more testing\n iterations (the function uses 64 iterations internally, which is typically\n more than sufficient). The Miller-Rabin test is particularly useful for large\n numbers.\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   Examples of prime numbers:\n   - \\\\(2\\\\) is a prime number since it has only two divisors: \\\\(1\\\\) and \\\\(2\\\\).\n   - \\\\(7\\\\) is a prime number since it has only two divisors: \\\\(1\\\\) and \\\\(7\\\\).\n   - \\\\(4\\\\) is not a prime number since it has divisors other than \\\\(1\\\\) and itself, such\n     as \\\\(2\\\\).\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.is_prime(2)\n       |&gt; should.equal(True)\n\n       maths.is_prime(4)\n       |&gt; should.equal(False)\n\n       // Test the 2nd Carmichael number\n       maths.is_prime(1105)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.is_prime\ngleam_community/maths is_prime","url":"gleam_community/maths.html#is_prime"},{"doc":"gleam_community/maths","title":"jaccard_index","content":"pub fn jaccard_index(xset: Set(a), yset: Set(a)) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The Jaccard index measures similarity between two sets of elements. Mathematically, the\n Jaccard index is defined as:\n\n \\\\[\n \\frac{|X \\cap Y|}{|X \\cup Y|} \\\\; \\in \\\\; \\left[0, 1\\right]\n \\\\]\n\n where:\n\n - \\\\(X\\\\) and \\\\(Y\\\\) are two sets being compared\n - \\\\(|X \\cap Y|\\\\) represents the size of the intersection of the two sets\n - \\\\(|X \\cup Y|\\\\) denotes the size of the union of the two sets\n\n The value of the Jaccard index ranges from 0 to 1, where 0 indicates that the\n two sets share no elements and 1 indicates that the sets are identical. The\n Jaccard index is a special case of the  [Tversky index](#tversky_index) (with\n \\\\(\\alpha=\\beta=1\\\\)).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/set\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let xset = set.from_list([&quot;cat&quot;, &quot;dog&quot;, &quot;hippo&quot;, &quot;monkey&quot;])\n       let yset = set.from_list([&quot;monkey&quot;, &quot;rhino&quot;, &quot;ostrich&quot;, &quot;salmon&quot;])\n       maths.jaccard_index(xset, yset)\n       |&gt; should.equal(1.0 /. 7.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.jaccard_index\ngleam_community/maths jaccard_index","url":"gleam_community/maths.html#jaccard_index"},{"doc":"gleam_community/maths","title":"kurtosis","content":"pub fn kurtosis(arr: List(Float)) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the sample kurtosis of a list of elements using the\n definition of Fisher.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.kurtosis()\n       |&gt; should.be_error()\n\n       // To calculate kurtosis at least four values are needed\n       [1.0, 2.0, 3.0]\n       |&gt; maths.kurtosis()\n       |&gt; should.be_error()\n\n       [1.0, 2.0, 3.0, 4.0]\n       |&gt; maths.kurtosis()\n       |&gt; should.equal(Ok(-1.36))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.kurtosis\ngleam_community/maths kurtosis","url":"gleam_community/maths.html#kurtosis"},{"doc":"gleam_community/maths","title":"lcm","content":"pub fn lcm(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function calculates the least common multiple of two integers\n \\\\(x, y \\in \\mathbb{Z}\\\\). The least common multiple is the smallest positive\n integer that has both \\\\(x\\\\) and \\\\(y\\\\) as factors.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.lcm(1, 1)\n       |&gt; should.equal(1)\n\n       maths.lcm(100, 10)\n       |&gt; should.equal(100)\n\n       maths.lcm(-36, -17)\n       |&gt; should.equal(612)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.lcm\ngleam_community/maths lcm","url":"gleam_community/maths.html#lcm"},{"doc":"gleam_community/maths","title":"linear_space","content":"pub fn linear_space(\n  start: Float,\n  stop: Float,\n  steps: Int,\n  endpoint: Bool,\n) -&gt; Result(List(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns a list of linearly spaced points over a specified\n interval. The endpoint of the interval can optionally be included/excluded. The number of\n points and whether the endpoint is included determine the spacing between values.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n       let assert Ok(linspace) = maths.linear_space(10.0, 20.0, 5, True)\n       let pairs = linspace |&gt; list.zip([10.0, 12.5, 15.0, 17.5, 20.0])\n       let assert Ok(result) = maths.all_close(pairs, 0.0, tolerance)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n\n       // A negative number of points (-5) does not work\n       maths.linear_space(10.0, 50.0, -5, True)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.linear_space\ngleam_community/maths linear_space","url":"gleam_community/maths.html#linear_space"},{"doc":"gleam_community/maths","title":"list_combination","content":"pub fn list_combination(\n  arr: List(a),\n  k: Int,\n) -&gt; Result(Yielder(List(a)), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generates all possible combinations of \\\\(k\\\\) elements selected from a given list of size\n \\\\(n\\\\). The function handles the case without repetitions, that is, repeated elements\n are not treated as distinct.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // All 2-combinations of [1, 2, 3] without repetition\n       let assert Ok(combinations) = maths.list_combination([1, 2, 3], 2)\n\n       combinations\n       |&gt; yielder.to_list()\n       |&gt; should.equal([[1, 2], [1, 3], [2, 3]])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.list_combination\ngleam_community/maths list_combination","url":"gleam_community/maths.html#list_combination"},{"doc":"gleam_community/maths","title":"list_combination_with_repetitions","content":"pub fn list_combination_with_repetitions(\n  arr: List(a),\n  k: Int,\n) -&gt; Result(Yielder(List(a)), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generates all possible combinations of \\\\(k\\\\) elements selected from a given list of size\n \\\\(n\\\\). The function handles the case when the repetition of elements is allowed, that is,\n repeated elements are treated as distinct.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // All 2-combinations of [1, 2, 3] with repetition\n       let assert Ok(combinations) =\n         maths.list_combination_with_repetitions([1, 2, 3], 2)\n\n       combinations\n       |&gt; yielder.to_list()\n       |&gt; should.equal([[1, 1], [1, 2], [1, 3], [2, 2], [2, 3], [3, 3]])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.list_combination_with_repetitions\ngleam_community/maths list_combination_with_repetitions","url":"gleam_community/maths.html#list_combination_with_repetitions"},{"doc":"gleam_community/maths","title":"list_maximum","content":"pub fn list_maximum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(a, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the maximum value of a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/float\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.list_maximum(float.compare)\n       |&gt; should.be_error()\n\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; maths.list_maximum(float.compare)\n       |&gt; should.equal(Ok(4.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.list_maximum\ngleam_community/maths list_maximum","url":"gleam_community/maths.html#list_maximum"},{"doc":"gleam_community/maths","title":"list_minimum","content":"pub fn list_minimum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(a, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the minimum value of a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/int\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.list_minimum(int.compare)\n       |&gt; should.be_error()\n\n       [4, 4, 3, 2, 1]\n       |&gt; maths.list_minimum(int.compare)\n       |&gt; should.equal(Ok(1))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\ngleam_community/maths.list_minimum\ngleam_community/maths list_minimum","url":"gleam_community/maths.html#list_minimum"},{"doc":"gleam_community/maths","title":"list_permutation","content":"pub fn list_permutation(\n  arr: List(a),\n  k: Int,\n) -&gt; Result(Yielder(List(a)), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generates all possible permutations of \\\\(k\\\\) elements selected from a given list of size\n \\\\(n\\\\). The function handles the case without repetitions, that is, repeated elements are\n not treated as distinct.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // All 2-permutations of [1, 2] without repetition\n       let assert Ok(permutations) =\n         [1, 2]\n         |&gt; maths.list_permutation(2)\n       permutations\n       |&gt; yielder.to_list()\n       |&gt; should.equal([[1, 2], [2, 1]])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.list_permutation\ngleam_community/maths list_permutation","url":"gleam_community/maths.html#list_permutation"},{"doc":"gleam_community/maths","title":"list_permutation_with_repetitions","content":"pub fn list_permutation_with_repetitions(\n  arr: List(a),\n  k: Int,\n) -&gt; Result(Yielder(List(a)), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generates all possible permutations of \\\\(k\\\\) elements selected from a given list of size\n \\\\(n\\\\). The function handles the case when the repetition of elements is allowed, that is,\n repeated elements are treated as distinct.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // All 2-permutations of [1, 2] with repetition\n       let assert Ok(permutations) =\n         [1, 2]\n         |&gt; maths.list_permutation_with_repetitions(2)\n       permutations\n       |&gt; yielder.to_list()\n       |&gt; set.from_list()\n       |&gt; should.equal(set.from_list([[1, 1], [1, 2], [2, 2], [2, 1]]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.list_permutation_with_repetitions\ngleam_community/maths list_permutation_with_repetitions","url":"gleam_community/maths.html#list_permutation_with_repetitions"},{"doc":"gleam_community/maths","title":"logarithm","content":"pub fn logarithm(x: Float, base: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The base \\\\(b\\\\) logarithm function (computed through the &quot;change of base&quot; formula):\n\n \\\\[\n \\forall x \\in \\(0, \\infty\\) \\textnormal{ and } b &gt; 1,  \\\\; \\log_{b}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(0, \\infty\\)\\\\) and a base \\\\(b &gt; 1\\\\)\n as input and returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\(-\\infty, \\infty\\)\\\\).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.logarithm(1.0, 10.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.logarithm(maths.e(), maths.e())\n       |&gt; should.equal(Ok(1.0))\n\n       maths.logarithm(-1.0, 2.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.logarithm\ngleam_community/maths logarithm","url":"gleam_community/maths.html#logarithm"},{"doc":"gleam_community/maths","title":"logarithm_10","content":"pub fn logarithm_10(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The base-10 logarithm function:\n\n \\\\[\n \\forall x \\in \\(0, \\infty),   \\\\; \\log_{10}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(0, \\infty\\)\\\\) as input and returns a\n numeric value \\\\(y\\\\) that lies in the range \\\\(\\(-\\infty, \\infty\\)\\\\).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.logarithm_10(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.logarithm_10(10.0)\n       |&gt; should.equal(Ok(1.0))\n\n       maths.logarithm_10(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.logarithm_10\ngleam_community/maths logarithm_10","url":"gleam_community/maths.html#logarithm_10"},{"doc":"gleam_community/maths","title":"logarithm_2","content":"pub fn logarithm_2(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The base-2 logarithm function:\n\n \\\\[\n \\forall x \\in \\(0, \\infty),   \\\\; \\log_{2}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(0, \\infty\\)\\\\) as input and returns a\n numeric value \\\\(y\\\\) that lies in the range \\\\(\\(-\\infty, \\infty\\)\\\\).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.logarithm_2(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.logarithm_2(2.0)\n       |&gt; should.equal(Ok(1.0))\n\n       maths.logarithm_2(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.logarithm_2\ngleam_community/maths logarithm_2","url":"gleam_community/maths.html#logarithm_2"},{"doc":"gleam_community/maths","title":"logarithmic_space","content":"pub fn logarithmic_space(\n  start: Float,\n  stop: Float,\n  steps: Int,\n  endpoint: Bool,\n  base: Float,\n) -&gt; Result(List(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns a list of logarithmically spaced points over a specified\n interval. The endpoint of the interval can optionally be included/excluded.\n The number of points, base, and whether the endpoint is included determine\n the spacing between values.\n\n The values in the sequence are computed as powers of the given base, where\n the exponents are evenly spaced between `start` and `stop`. The `base`\n parameter must be positive, as negative bases lead to undefined behavior when\n computing fractional exponents. Similarly, the number of points (`steps`) must\n be positive; specifying zero or a negative value will result in an error.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n       let assert Ok(logspace) = maths.logarithmic_space(1.0, 3.0, 3, True, 10.0)\n       let pairs = logspace |&gt; list.zip([10.0, 100.0, 1000.0])\n       let assert Ok(result) = maths.all_close(pairs, 0.0, tolerance)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n\n       // A negative number of points (-3) does not work\n       maths.logarithmic_space(1.0, 3.0, -3, False, 10.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.logarithmic_space\ngleam_community/maths logarithmic_space","url":"gleam_community/maths.html#logarithmic_space"},{"doc":"gleam_community/maths","title":"manhattan_distance","content":"pub fn manhattan_distance(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the Manhattan distance between two lists (representing\n vectors):\n\n \\\\[\n \\sum_{i=1}^n \\left|x_i - y_i \\right|\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.manhattan_distance([#(1.0, 2.0), #(2.0, 3.0)])\n       |&gt; should.equal(Ok(2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.manhattan_distance\ngleam_community/maths manhattan_distance","url":"gleam_community/maths.html#manhattan_distance"},{"doc":"gleam_community/maths","title":"manhattan_distance_with_weights","content":"pub fn manhattan_distance_with_weights(\n  arr: List(#(Float, Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted Manhattan distance between two lists (representing\n vectors):\n\n \\\\[\n \\sum_{i=1}^n w_{i} \\left|x_i - y_i \\right|\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the two lists and \\\\(x_i, y_i\\\\) are the\n values in the respective input lists indexed by \\\\(i\\\\), while the\n \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.manhattan_distance_with_weights([#(1.0, 2.0, 0.5), #(2.0, 3.0, 1.0)])\n       |&gt; should.equal(Ok(1.5))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.manhattan_distance_with_weights\ngleam_community/maths manhattan_distance_with_weights","url":"gleam_community/maths.html#manhattan_distance_with_weights"},{"doc":"gleam_community/maths","title":"mean","content":"pub fn mean(arr: List(Float)) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the arithmetic mean of the elements in a list:\n\n \\\\[\n \\bar{x} = \\frac{1}{n}\\sum_{i=1}^n x_i\n \\\\]\n\n In the formula, \\\\(n\\\\) is the sample size (the length of the list) and \\\\(x_i\\\\)\n is the sample point in the input list indexed by \\\\(i\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.mean()\n       |&gt; should.be_error()\n\n       [1.0, 2.0, 3.0]\n       |&gt; maths.mean()\n       |&gt; should.equal(Ok(2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.mean\ngleam_community/maths mean","url":"gleam_community/maths.html#mean"},{"doc":"gleam_community/maths","title":"median","content":"pub fn median(arr: List(Float)) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the median of the elements in a list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.median()\n       |&gt; should.be_error()\n\n       [1.0, 2.0, 3.0]\n       |&gt; maths.median()\n       |&gt; should.equal(Ok(2.0))\n\n       [1.0, 2.0, 3.0, 4.0]\n       |&gt; maths.median()\n       |&gt; should.equal(Ok(2.5))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.median\ngleam_community/maths median","url":"gleam_community/maths.html#median"},{"doc":"gleam_community/maths","title":"minkowski_distance","content":"pub fn minkowski_distance(\n  arr: List(#(Float, Float)),\n  p: Float,\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the Minkowski distance between two lists (representing\n vectors):\n\n \\\\[\n \\left( \\sum_{i=1}^n w_{i} \\left|x_i - y_i \\right|^{p} \\right)^{\\frac{1}{p}}\n \\\\]\n\n In the formula, \\\\(p &gt;= 1\\\\) is the order, \\\\(n\\\\) is the length of the two lists\n and \\\\(x_i, y_i\\\\) are the values in the respective input lists indexed by \\\\(i\\\\).\n\n The Minkowski distance is a generalization of the Euclidean distance\n (\\\\(p=2\\\\)) and the Manhattan distance (\\\\(p = 1\\\\)).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n\n       let assert Ok(result) =\n         maths.minkowski_distance([#(1.0, 2.0), #(3.0, 4.0), #(5.0, 6.0)], 4.0)\n       result\n       |&gt; maths.is_close(1.3160740129524924, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.minkowski_distance\ngleam_community/maths minkowski_distance","url":"gleam_community/maths.html#minkowski_distance"},{"doc":"gleam_community/maths","title":"minkowski_distance_with_weights","content":"pub fn minkowski_distance_with_weights(\n  arr: List(#(Float, Float, Float)),\n  p: Float,\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted Minkowski distance between two lists (representing\n vectors):\n\n \\\\[\n \\left( \\sum_{i=1}^n w_{i} \\left|x_i - y_i \\right|^{p} \\right)^{\\frac{1}{p}}\n \\\\]\n\n In the formula, \\\\(p &gt;= 1\\\\) is the order, \\\\(n\\\\) is the length of the two lists\n and \\\\(x_i, y_i\\\\) are the values in the respective input lists indexed by \\\\(i\\\\).\n The \\\\(w_i \\in \\mathbb{R}_{+}\\\\) are corresponding positive weights.\n\n The Minkowski distance is a generalization of the Euclidean distance\n (\\\\(p=2\\\\)) and the Manhattan distance (\\\\(p = 1\\\\)).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n\n       let assert Ok(result) =\n         maths.minkowski_distance_with_weights(\n           [#(1.0, 2.0, 0.5), #(3.0, 4.0, 1.0), #(5.0, 6.0, 1.0)],\n           4.0,\n         )\n       result\n       |&gt; maths.is_close(1.2574334296829355, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.minkowski_distance_with_weights\ngleam_community/maths minkowski_distance_with_weights","url":"gleam_community/maths.html#minkowski_distance_with_weights"},{"doc":"gleam_community/maths","title":"minmax","content":"pub fn minmax(x: a, y: a, compare: fn(a, a) -&gt; Order) -&gt; #(a, a)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The minmax function takes two arguments \\\\(x, y\\\\) along with a function\n for comparing \\\\(x, y\\\\). The function returns a tuple with the smallest\n value first and largest second.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleam/float\n     import gleam/int\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.minmax(2.0, 1.5, float.compare)\n       |&gt; should.equal(#(1.5, 2.0))\n\n       maths.minmax(1, 2, int.compare)\n       |&gt; should.equal(#(1, 2))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.minmax\ngleam_community/maths minmax","url":"gleam_community/maths.html#minmax"},{"doc":"gleam_community/maths","title":"moment","content":"pub fn moment(arr: List(Float), n: Int) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the n&#39;th moment about the mean of a list of elements.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.moment(0)\n       |&gt; should.be_error()\n\n       // 0th moment about the mean is 1. per definition\n       [0.0, 1.0, 2.0, 3.0, 4.0]\n       |&gt; maths.moment(0)\n       |&gt; should.equal(Ok(1.0))\n\n       // 1st moment about the mean is 0. per definition\n       [0.0, 1.0, 2.0, 3.0, 4.0]\n       |&gt; maths.moment(1)\n       |&gt; should.equal(Ok(0.0))\n\n       // 2nd moment about the mean\n       [0.0, 1.0, 2.0, 3.0, 4.0]\n       |&gt; maths.moment(2)\n       |&gt; should.equal(Ok(2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.moment\ngleam_community/maths moment","url":"gleam_community/maths.html#moment"},{"doc":"gleam_community/maths","title":"natural_logarithm","content":"pub fn natural_logarithm(x: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The natural logarithm function:\n\n \\\\[\n \\forall x \\in \\(0, \\infty\\),   \\\\; \\log_{e}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(0, \\infty\\)\\\\) as input and returns\n a numeric value \\\\(y\\\\) that lies in the range \\\\(\\(-\\infty, \\infty\\)\\\\).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.natural_logarithm(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       maths.natural_logarithm(maths.e())\n       |&gt; should.equal(Ok(1.0))\n\n       maths.natural_logarithm(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.natural_logarithm\ngleam_community/maths natural_logarithm","url":"gleam_community/maths.html#natural_logarithm"},{"doc":"gleam_community/maths","title":"norm","content":"pub fn norm(arr: List(Float), p: Float) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the \\\\(p\\\\)-norm of a list (representing a vector):\n\n \\\\[\n \\left( \\sum_{i=1}^n \\left|x_{i}\\right|^{p} \\right)^{\\frac{1}{p}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the list and \\\\(x_i\\\\) is the value in\n the input list indexed by \\\\(i\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       [1.0, 1.0, 1.0]\n       |&gt; maths.norm(1.0)\n       |&gt; should.equal(Ok(3.0))\n\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n       let assert Ok(result) =\n         [1.0, 2.0, 3.0]\n         |&gt; maths.norm(2.0)\n       result\n       |&gt; maths.is_close(3.7416573867739413, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.norm\ngleam_community/maths norm","url":"gleam_community/maths.html#norm"},{"doc":"gleam_community/maths","title":"norm_with_weights","content":"pub fn norm_with_weights(\n  arr: List(#(Float, Float)),\n  p: Float,\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted \\\\(p\\\\)-norm of a list (representing a vector):\n\n \\\\[\n \\left( \\sum_{i=1}^n w_{i} \\left|x_{i}\\right|^{p} \\right)^{\\frac{1}{p}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the list and \\\\(x_i\\\\) is the value in\n the input list indexed by \\\\(i\\\\), while \\\\(w_i \\in \\mathbb{R}_{+}\\\\) is\n a corresponding positive weight.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       [#(1.0, 0.5), #(1.0, 0.5), #(1.0, 0.5)]\n       |&gt; maths.norm_with_weights(1.0)\n       |&gt; should.equal(Ok(1.5))\n\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n       let assert Ok(result) =\n         [#(1.0, 0.5), #(2.0, 0.5), #(3.0, 0.5)]\n         |&gt; maths.norm_with_weights(2.0)\n       result\n       |&gt; maths.is_close(2.6457513110645907, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.norm_with_weights\ngleam_community/maths norm_with_weights","url":"gleam_community/maths.html#norm_with_weights"},{"doc":"gleam_community/maths","title":"nth_root","content":"pub fn nth_root(x: Float, n: Int) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The \\\\(n\\\\)&#39;th root function: \\\\(y = \\sqrt[n]{x} = x^{\\frac{1}{n}}\\\\).\n\n Note that the function is not defined if the input is negative (\\\\(x &lt; 0\\\\)). An error will be\n returned as an imaginary number will otherwise have to be returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.nth_root(-1.0, 2)\n       |&gt; should.be_error()\n\n       maths.nth_root(1.0, 2)\n       |&gt; should.equal(Ok(1.0))\n\n       maths.nth_root(27.0, 3)\n       |&gt; should.equal(Ok(3.0))\n\n       maths.nth_root(256.0, 4)\n       |&gt; should.equal(Ok(4.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.nth_root\ngleam_community/maths nth_root","url":"gleam_community/maths.html#nth_root"},{"doc":"gleam_community/maths","title":"overlap_coefficient","content":"pub fn overlap_coefficient(xset: Set(a), yset: Set(a)) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The Overlap coefficient, also known as the Szymkiewicz–Simpson coefficient, is\n a measure of similarity between two sets that focuses on the size of the\n intersection relative to the smaller of the two sets. It is defined\n mathematically as:\n\n \\\\[\n \\frac{|X \\cap Y|}{\\min(|X|, |Y|)} \\\\; \\in \\\\; \\left[0, 1\\right]\n \\\\]\n\n where:\n\n - \\\\(X\\\\) and \\\\(Y\\\\) are the sets being compared\n - \\\\(|X \\cap Y|\\\\) is the size of the intersection of the sets\n - \\\\(\\min(|X|, |Y|)\\\\) is the size of the smaller set among \\\\(X\\\\) and \\\\(Y\\\\)\n\n The coefficient ranges from 0 to 1, where 0 indicates no overlap and 1\n indicates that the smaller set is a suyset of the larger set. This\n measure is especially useful in situations where the similarity in terms\n of the proportion of overlap is more relevant than the difference in sizes\n between the two sets.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/set\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let set_a = set.from_list([&quot;horse&quot;, &quot;dog&quot;, &quot;hippo&quot;, &quot;monkey&quot;, &quot;bird&quot;])\n       let set_b = set.from_list([&quot;monkey&quot;, &quot;bird&quot;, &quot;ostrich&quot;, &quot;salmon&quot;])\n       maths.overlap_coefficient(set_a, set_b)\n       |&gt; should.equal(2.0 /. 4.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.overlap_coefficient\ngleam_community/maths overlap_coefficient","url":"gleam_community/maths.html#overlap_coefficient"},{"doc":"gleam_community/maths","title":"percentile","content":"pub fn percentile(arr: List(Float), n: Int) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the n&#39;th percentile of the elements in a list using\n linear interpolation between closest ranks.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.percentile(40)\n       |&gt; should.be_error()\n\n       // Calculate 40th percentile\n       [15.0, 20.0, 35.0, 40.0, 50.0]\n       |&gt; maths.percentile(40)\n       |&gt; should.equal(Ok(29.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.percentile\ngleam_community/maths percentile","url":"gleam_community/maths.html#percentile"},{"doc":"gleam_community/maths","title":"permutation","content":"pub fn permutation(n: Int, k: Int) -&gt; Result(Int, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the number of \\\\(k\\\\)-permutations without\n repetitions:\n\n \\\\[\n P(n, k) = \\binom{n}{k} \\cdot k! = \\frac{n!}{(n - k)!}\n \\\\]\n\n The implementation uses an efficient iterative multiplicative formula for computing the result.\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n A \\\\(k\\\\)-permutation without repetitions is a sequence of \\\\(k\\\\) elements selected from \\\n \\\\(n\\\\) elements where the order of selection matters and elements are not allowed to repeat.\n For example, consider selecting 2 elements from a list of 3 elements: `[&quot;A&quot;, &quot;B&quot;, &quot;C&quot;]`. In\n this case, possible selections are:\n   - `[&quot;A&quot;, &quot;B&quot;], [&quot;B&quot;, &quot;A&quot;]`\n   - `[&quot;A&quot;, &quot;C&quot;], [&quot;C&quot;, &quot;A&quot;]`\n   - `[&quot;B&quot;, &quot;C&quot;], [&quot;C&quot;, &quot;B&quot;]`\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.permutation(-1, 1)\n       |&gt; should.be_error()\n\n       maths.permutation(4, 0)\n       |&gt; should.equal(Ok(1))\n\n       maths.permutation(4, 2)\n       |&gt; should.equal(Ok(12))\n\n       maths.permutation(13, 5)\n       |&gt; should.equal(Ok(154_440))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.permutation\ngleam_community/maths permutation","url":"gleam_community/maths.html#permutation"},{"doc":"gleam_community/maths","title":"permutation_with_repetitions","content":"pub fn permutation_with_repetitions(\n  n: Int,\n  k: Int,\n) -&gt; Result(Int, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the number of \\\\(k\\\\)-permutations with repetitions:\n\n \\\\[\n P^*(n, k) = n^k\n \\\\]\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n A \\\\(k\\\\)-permutation with repetitions is a sequence of \\\\(k\\\\) elements selected from \\\\(n\\\\)\n elements where the order of selection matters and elements are allowed to repeat. For example,\n consider selecting 2 elements from a list of 3 elements: `[&quot;A&quot;, &quot;B&quot;, &quot;C&quot;]`. In this case,\n possible selections are:\n   - `[&quot;A&quot;, &quot;A&quot;], [&quot;A&quot;, &quot;B&quot;], [&quot;A&quot;, &quot;C&quot;]`\n   - `[&quot;B&quot;, &quot;A&quot;], [&quot;B&quot;, &quot;B&quot;], [&quot;B&quot;, &quot;C&quot;]`\n   - `[&quot;C&quot;, &quot;A&quot;], [&quot;C&quot;, &quot;B&quot;], [&quot;C&quot;, &quot;C&quot;]`\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.permutation_with_repetitions(1, -1)\n       |&gt; should.be_error()\n\n       maths.permutation_with_repetitions(2, 3)\n       |&gt; should.equal(Ok(8))\n\n       maths.permutation_with_repetitions(4, 4)\n       |&gt; should.equal(Ok(256))\n\n       maths.permutation_with_repetitions(6, 3)\n       |&gt; should.equal(Ok(216))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.permutation_with_repetitions\ngleam_community/maths permutation_with_repetitions","url":"gleam_community/maths.html#permutation_with_repetitions"},{"doc":"gleam_community/maths","title":"pi","content":"pub fn pi() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The mathematical constant pi: \\\\(\\pi \\approx 3.1415\\dots\\\\)\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.pi\ngleam_community/maths pi","url":"gleam_community/maths.html#pi"},{"doc":"gleam_community/maths","title":"polar_to_cartesian","content":"pub fn polar_to_cartesian(\n  r: Float,\n  theta: Float,\n) -&gt; #(Float, Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Converts polar coordinates \\\\((r, \\theta)\\\\) to Cartesian coordinates \\\\((x, y)\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.polar_to_cartesian(1.0, 0.0)\n       |&gt; should.equal(#(1.0, 0.0))\n\n       maths.polar_to_cartesian(1.0, float.pi() /. 2.0)\n       |&gt; should.equal(#(0.0, 1.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.polar_to_cartesian\ngleam_community/maths polar_to_cartesian","url":"gleam_community/maths.html#polar_to_cartesian"},{"doc":"gleam_community/maths","title":"proper_divisors","content":"pub fn proper_divisors(n: Int) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns all the positive divisors of an integer, excluding the\n number itself.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.proper_divisors(4)\n       |&gt; should.equal([1, 2])\n\n       maths.proper_divisors(6)\n       |&gt; should.equal([1, 2, 3])\n\n       maths.proper_divisors(13)\n       |&gt; should.equal([1])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.proper_divisors\ngleam_community/maths proper_divisors","url":"gleam_community/maths.html#proper_divisors"},{"doc":"gleam_community/maths","title":"radians_to_degrees","content":"pub fn radians_to_degrees(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Convert a value in degrees to a value measured in radians.\n That is, \\\\(1 \\text{ radians } = \\frac{180}{\\pi} \\text{ degrees }\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.radians_to_degrees(0.0)\n       |&gt; should.equal(0.0)\n\n       maths.radians_to_degrees(2. *. maths.pi())\n       |&gt; should.equal(360.)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.radians_to_degrees\ngleam_community/maths radians_to_degrees","url":"gleam_community/maths.html#radians_to_degrees"},{"doc":"gleam_community/maths","title":"round_down","content":"pub fn round_down(x: Float, p: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before\n if negative). In particular, the input \\\\(x\\\\) is rounded to the nearest integer value (at the\n specified digit) that is less than or equal to the input \\\\(x\\\\). This rounding behaviour is\n similar to behaviour of the Gleam stdlib `floor` function.\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The rounding mode rounds \\\\(12.0654\\\\) to:\n   - \\\\(12.0\\\\) for 0 digits after the decimal point (`digits = 0`)\n   - \\\\(12.0\\\\) for 1 digits after the decimal point (`digits = 1`)\n   - \\\\(12.06\\\\) for 2 digits after the decimal point (`digits = 2`)\n   - \\\\(12.065\\\\) for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative\n   number refers to the digits before the decimal point.\n   - \\\\(10.0\\\\) for 1 digit before the decimal point (`digits = -1`)\n   - \\\\(0.0\\\\) for 2 digits before the decimal point (`digits = -2`)\n   - \\\\(0.0\\\\) for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.round_down(12.0654, 2)\n       |&gt; should.equal(12.06)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.round_down\ngleam_community/maths round_down","url":"gleam_community/maths.html#round_down"},{"doc":"gleam_community/maths","title":"round_ties_away","content":"pub fn round_ties_away(x: Float, p: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before\n if negative). In particular, the input \\\\(x\\\\) is rounded to the nearest integer value (at the\n specified digit) with ties (fractional values of 0.5) being rounded away from zero (C/C++\n rounding behaviour).\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The rounding mode rounds \\\\(12.0654\\\\) to:\n   - \\\\(12.0\\\\) for 0 digits after the decimal point (`digits = 0`)\n   - \\\\(12.1\\\\) for 1 digit after the decimal point (`digits = 1`)\n   - \\\\(12.07\\\\) for 2 digits after the decimal point (`digits = 2`)\n   - \\\\(12.065\\\\) for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative\n   number refers to the digits before the decimal point.\n   - \\\\(10.0\\\\) for 1 digit before the decimal point (`digits = -1`)\n   - \\\\(0.0\\\\) for 2 digits before the decimal point (`digits = -2`)\n   - \\\\(0.0\\\\) for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.round_ties_away(12.0654, 2)\n       |&gt; should.equal(12.07)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.round_ties_away\ngleam_community/maths round_ties_away","url":"gleam_community/maths.html#round_ties_away"},{"doc":"gleam_community/maths","title":"round_ties_up","content":"pub fn round_ties_up(x: Float, p: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before\n if negative). In particular, the input \\\\(x\\\\) is rounded to the nearest integer value (at the\n specified digit) with ties (fractional values of 0.5) being rounded towards \\\\(+\\infty\\\\)\n (Java/JavaScript rounding behaviour).\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The rounding mode rounds \\\\(12.0654\\\\) to:\n   - \\\\(12.0\\\\) for 0 digits after the decimal point (`digits = 0`)\n   - \\\\(12.1\\\\) for 1 digits after the decimal point (`digits = 1`)\n   - \\\\(12.07\\\\) for 2 digits after the decimal point (`digits = 2`)\n   - \\\\(12.065\\\\) for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative\n    number refers to the digits before the decimal point.\n   - \\\\(10.0\\\\) for 1 digit before the decimal point (`digits = -1`)\n   - \\\\(0.0\\\\) for 2 digits before the decimal point (`digits = -2`)\n   - \\\\(0.0\\\\) for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.round_ties_up(12.0654, 2)\n       |&gt; should.equal(12.07)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.round_ties_up\ngleam_community/maths round_ties_up","url":"gleam_community/maths.html#round_ties_up"},{"doc":"gleam_community/maths","title":"round_to_nearest","content":"pub fn round_to_nearest(x: Float, p: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before\n if negative). In particular, the input \\\\(x\\\\) is rounded to the nearest integer value (at the\n specified digit) with ties (fractional values of 0.5) being rounded to the nearest even\n integer.\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The rounding mode rounds \\\\(12.0654\\\\) to:\n   - \\\\(12.0\\\\) for 0 digits after the decimal point (`digits = 0`)\n   - \\\\(12.1\\\\) for 1 digit after the decimal point (`digits = 1`)\n   - \\\\(12.07\\\\) for 2 digits after the decimal point (`digits = 2`)\n   - \\\\(12.065\\\\) for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative\n   number refers to the digits before the decimal point.\n   - \\\\(10.0\\\\) for 1 digit before the decimal point (`digits = -1`)\n   - \\\\(0.0\\\\) for 2 digits before the decimal point (`digits = -2`)\n   - \\\\(0.0\\\\) for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.round_to_nearest(12.0654, 2)\n       |&gt; should.equal(12.07)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.round_to_nearest\ngleam_community/maths round_to_nearest","url":"gleam_community/maths.html#round_to_nearest"},{"doc":"gleam_community/maths","title":"round_to_zero","content":"pub fn round_to_zero(x: Float, p: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before\n if negative). In particular, the input \\\\(x\\\\) is rounded to the nearest integer value (at the\n specified digit) that is less than or equal to the absolute value of the input \\\\(x\\\\). This\n rounding behaviour is similar to behaviour of the Gleam stdlib `truncate` function.\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The rounding mode rounds \\\\(12.0654\\\\) to:\n   - \\\\(12.0\\\\) for 0 digits after the decimal point (`digits = 0`)\n   - \\\\(12.0\\\\) for 1 digit after the decimal point (`digits = 1`)\n   - \\\\(12.06\\\\) for 2 digits after the decimal point (`digits = 2`)\n   - \\\\(12.065\\\\) for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative\n   number refers to the digits before the decimal point.\n   - \\\\(10.0\\\\) for 1 digit before the decimal point (`digits = -1`)\n   - \\\\(0.0\\\\) for 2 digits before the decimal point (`digits = -2`)\n   - \\\\(0.0\\\\) for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.round_to_zero(12.0654, 2)\n       |&gt; should.equal(12.06)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.round_to_zero\ngleam_community/maths round_to_zero","url":"gleam_community/maths.html#round_to_zero"},{"doc":"gleam_community/maths","title":"round_up","content":"pub fn round_up(x: Float, p: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before\n if negative). In particular, the input \\\\(x\\\\) is rounded to the nearest integer value (at the\n specified digit) that is larger than or equal to the input \\\\(x\\\\). This rounding behaviour is\n similar to behaviour of the Gleam stdlib `ceiling` function.\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The rounding mode rounds \\\\(12.0654\\\\) to:\n   - \\\\(13.0\\\\) for 0 digits after the decimal point (`digits = 0`)\n   - \\\\(12.1\\\\) for 1 digit after the decimal point (`digits = 1`)\n   - \\\\(12.07\\\\) for 2 digits after the decimal point (`digits = 2`)\n   - \\\\(12.066\\\\) for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative\n   number refers to the digits before the decimal point.\n   - \\\\(20.0\\\\) for 1 digit places before the decimal point (`digit = -1`)\n   - \\\\(100.0\\\\) for 2 digits before the decimal point (`digits = -2`)\n   - \\\\(1000.0\\\\) for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.round_up(12.0654, 2)\n       |&gt; should.equal(12.07)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.round_up\ngleam_community/maths round_up","url":"gleam_community/maths.html#round_up"},{"doc":"gleam_community/maths","title":"sign","content":"pub fn sign(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes an input \\\\(x \\in \\mathbb{R}\\\\) and returns the sign of\n the input, indicating whether it is positive (+1.0), negative (-1.0), or\n zero (0.0).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.sign\ngleam_community/maths sign","url":"gleam_community/maths.html#sign"},{"doc":"gleam_community/maths","title":"sin","content":"pub fn sin(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The sine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\sin{(x)} = y \\in \\[-1, 1\\]\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, \\infty\\)\\\\) (an angle in\n radians) as input and returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\[-1, 1\\]\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.sin(0.0)\n       |&gt; should.equal(0.0)\n\n       maths.sin(0.5 *. maths.pi())\n       |&gt; should.equal(1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.sin\ngleam_community/maths sin","url":"gleam_community/maths.html#sin"},{"doc":"gleam_community/maths","title":"sinh","content":"pub fn sinh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The hyperbolic sine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\sinh{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, +\\infty\\)\\\\) as input\n (an angle in radians) and returns a numeric value \\\\(y\\\\) that lies in the range\n \\\\(\\(-\\infty, +\\infty\\)\\\\). If the input value is too large an overflow error might occur.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.sinh(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.sinh\ngleam_community/maths sinh","url":"gleam_community/maths.html#sinh"},{"doc":"gleam_community/maths","title":"skewness","content":"pub fn skewness(arr: List(Float)) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the sample skewness of a list of elements using the\n Fisher-Pearson coefficient of skewness.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; maths.skewness()\n       |&gt; should.be_error()\n\n       // To calculate skewness at least three values are needed\n       [1.0, 2.0, 3.0]\n       |&gt; maths.skewness()\n       |&gt; should.equal(Ok(0.0))\n\n       [1.0, 1.0, 1.0, 1.0, 2.0, 2.0, 2.0, 3.0, 3.0, 4.0]\n       |&gt; maths.skewness()\n       |&gt; should.equal(Ok(0.6))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.skewness\ngleam_community/maths skewness","url":"gleam_community/maths.html#skewness"},{"doc":"gleam_community/maths","title":"sorensen_dice_coefficient","content":"pub fn sorensen_dice_coefficient(\n  xset: Set(a),\n  yset: Set(a),\n) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The Sørensen-Dice coefficient measures the similarity between two sets of elements.\n Mathematically, the coefficient is defined as:\n\n \\\\[\n \\frac{2 |X \\cap Y|}{|X| + |Y|} \\\\; \\in \\\\; \\left[0, 1\\right]\n \\\\]\n\n where:\n\n - \\\\(X\\\\) and \\\\(Y\\\\) are two sets being compared\n - \\\\(|X \\cap Y|\\\\) is the size of the intersection of the two sets (i.e., the\n number of elements common to both sets)\n - \\\\(|X|\\\\) and \\\\(|Y|\\\\) are the sizes of the sets \\\\(X\\\\) and \\\\(Y\\\\), respectively\n\n The coefficient ranges from 0 to 1, where 0 indicates no similarity (the sets\n share no elements) and 1 indicates perfect similarity (the sets are identical).\n The higher the coefficient, the greater the similarity between the two sets.\n The Sørensen-Dice coefficient is a special case of the\n [Tversky index](#tversky_index) (with \\\\(\\alpha=\\beta=0.5\\\\)).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/set\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let xset = set.from_list([&quot;cat&quot;, &quot;dog&quot;, &quot;hippo&quot;, &quot;monkey&quot;])\n       let yset = set.from_list([&quot;monkey&quot;, &quot;rhino&quot;, &quot;ostrich&quot;, &quot;salmon&quot;, &quot;spider&quot;])\n       maths.sorensen_dice_coefficient(xset, yset)\n       |&gt; should.equal(2.0 *. 1.0 /. { 4.0 +. 5.0 })\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.sorensen_dice_coefficient\ngleam_community/maths sorensen_dice_coefficient","url":"gleam_community/maths.html#sorensen_dice_coefficient"},{"doc":"gleam_community/maths","title":"standard_deviation","content":"pub fn standard_deviation(\n  arr: List(Float),\n  ddof: Int,\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the sample standard deviation of the elements in a list:\n \\\\[\n s = \\left(\\frac{1}{n - d} \\sum_{i=1}^{n}(x_i - \\bar{x})\\right)^{\\frac{1}{2}}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the sample size (the length of the list) and \\\\(x_i\\\\)\n is the sample point in the input list indexed by \\\\(i\\\\).\n Furthermore, \\\\(\\bar{x}\\\\) is the sample mean and \\\\(d\\\\) is the &quot;Delta\n Degrees of Freedom&quot;, and is typically set to \\\\(d = 1\\\\), which gives an unbiased estimate.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // Degrees of freedom\n       let ddof = 1\n\n       []\n       |&gt; maths.standard_deviation(ddof)\n       |&gt; should.be_error()\n\n       [1.0, 2.0, 3.0]\n       |&gt; maths.standard_deviation(ddof)\n       |&gt; should.equal(Ok(1.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.standard_deviation\ngleam_community/maths standard_deviation","url":"gleam_community/maths.html#standard_deviation"},{"doc":"gleam_community/maths","title":"step_range","content":"pub fn step_range(\n  start: Float,\n  stop: Float,\n  increment: Float,\n) -&gt; List(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns a list of evenly spaced values within a specified interval\n `[start, stop)` based on a given increment size.\n\n Note that if `increment &gt; 0`, the sequence progresses from `start`  towards `stop`, while if\n `increment &lt; 0`, the sequence progresses from `start` towards `stop` in reverse.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.step_range(1.0, 5.0, 1.0)\n       |&gt; should.equal([1.0, 2.0, 3.0, 4.0])\n\n       // No points returned since\n       // start is smaller than stop and the step is positive\n       maths.step_range(5.0, 1.0, 1.0)\n       |&gt; should.equal([])\n\n       // Points returned since\n       // start smaller than stop but negative step\n       maths.step_range(5.0, 1.0, -1.0)\n       |&gt; should.equal([5.0, 4.0, 3.0, 2.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.step_range\ngleam_community/maths step_range","url":"gleam_community/maths.html#step_range"},{"doc":"gleam_community/maths","title":"symmetric_space","content":"pub fn symmetric_space(\n  center: Float,\n  radius: Float,\n  steps: Int,\n) -&gt; Result(List(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generates evenly spaced points around a center value. The total span (around the center value)\n is determined by the `radius` argument of the function.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(symspace) = maths.symmetric_space(0.0, 5.0, 5)\n       symspace\n       |&gt; should.equal([-5.0, -2.5, 0.0, 2.5, 5.0])\n\n       // A negative radius reverses the order of the values\n       let assert Ok(symspace) = maths.symmetric_space(0.0, -5.0, 5)\n       symspace\n       |&gt; should.equal([5.0, 2.5, 0.0, -2.5, -5.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.symmetric_space\ngleam_community/maths symmetric_space","url":"gleam_community/maths.html#symmetric_space"},{"doc":"gleam_community/maths","title":"tan","content":"pub fn tan(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The tangent function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\tan{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, +\\infty\\)\\\\) as input\n (an angle in radians) and returns a numeric value \\\\(y\\\\) that lies in the range\n \\\\(\\(-\\infty, +\\infty\\)\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       maths.tan(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.tan\ngleam_community/maths tan","url":"gleam_community/maths.html#tan"},{"doc":"gleam_community/maths","title":"tanh","content":"pub fn tanh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The hyperbolic tangent function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\tanh{(x)} = y \\in \\[-1, 1\\]\n \\\\]\n\n The function takes a number \\\\(x\\\\) in its domain \\\\(\\(-\\infty, \\infty\\)\\\\) as input (an angle\n in radians) and returns a numeric value \\\\(y\\\\) that lies in the range \\\\(\\[-1, 1\\]\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       maths.tanh(0.0)\n       |&gt; should.equal(0.0)\n\n       maths.tanh(25.0)\n       |&gt; should.equal(1.0)\n\n       maths.tanh(-25.0)\n       |&gt; should.equal(-1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.tanh\ngleam_community/maths tanh","url":"gleam_community/maths.html#tanh"},{"doc":"gleam_community/maths","title":"tau","content":"pub fn tau() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The mathematical (circle) constant tau: \\\\(\\tau = 2 \\cdot \\pi \\approx 6.283\\dots\\\\)\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.tau\ngleam_community/maths tau","url":"gleam_community/maths.html#tau"},{"doc":"gleam_community/maths","title":"tversky_index","content":"pub fn tversky_index(\n  xset: Set(a),\n  yset: Set(a),\n  alpha: Float,\n  beta: Float,\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The Tversky index is a generalization of the Jaccard index and Sørensen-Dice\n coefficient, which adds flexibility in measuring similarity between two sets using two\n parameters, \\\\(\\alpha\\\\) and \\\\(\\beta\\\\). These parameters allow for asymmetric\n similarity measures between sets. The Tversky index is defined as:\n\n \\\\[\n \\frac{|X \\cap Y|}{|X \\cap Y| + \\alpha|X - Y| + \\beta|Y - X|}\n \\\\]\n\n where:\n\n - \\\\(X\\\\) and \\\\(Y\\\\) are the sets being compared\n - \\\\(|X - Y|\\\\) and \\\\(|Y - X|\\\\) are the sizes of the relative complements of\n \\\\(Y\\\\) in \\\\(X\\\\) and \\\\(X\\\\) in \\\\(Y\\\\), respectively,\n - \\\\(\\alpha\\\\) and \\\\(\\beta\\\\) are parameters that weight the relative importance\n of the elements unique to \\\\(X\\\\) and \\\\(Y\\\\)\n\n The Tversky index reduces to the Jaccard index when \\\\(\\alpha = \\beta = 1\\\\) and\n to the Sørensen-Dice coefficient when \\\\(\\alpha = \\beta = 0.5\\\\). In general, the\n Tversky index can take on any non-negative value, including 0. The index equals\n 0 when there is no intersection between the two sets, indicating no similarity.\n The Tversky index does not have a strict upper limit of 1 when \\\\(\\alpha \\neq \\beta\\\\).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/set\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let yset = set.from_list([&quot;cat&quot;, &quot;dog&quot;, &quot;hippo&quot;, &quot;monkey&quot;])\n       let xset = set.from_list([&quot;monkey&quot;, &quot;rhino&quot;, &quot;ostrich&quot;, &quot;salmon&quot;])\n       // Test Jaccard index (alpha = beta = 1)\n       maths.tversky_index(xset, yset, 1.0, 1.0)\n       |&gt; should.equal(Ok(1.0 /. 7.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.tversky_index\ngleam_community/maths tversky_index","url":"gleam_community/maths.html#tversky_index"},{"doc":"gleam_community/maths","title":"variance","content":"pub fn variance(\n  arr: List(Float),\n  ddof: Int,\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the sample variance of the elements in a list:\n\n \\\\[\n s^{2} = \\frac{1}{n - d} \\sum_{i=1}^{n}(x_i - \\bar{x})\n \\\\]\n\n In the formula, \\\\(n\\\\) is the sample size (the length of the list) and \\\\(x_i\\\\)\n is the sample point in the input list indexed by \\\\(i\\\\).\n Furthermore, \\\\(\\bar{x}\\\\) is the sample mean and \\\\(d\\\\) is the &quot;Delta\n Degrees of Freedom&quot;. It is typically set to \\\\(d = 1\\\\), which gives an unbiased estimate.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // Degrees of freedom\n       let ddof = 1\n\n       []\n       |&gt; maths.variance(ddof)\n       |&gt; should.be_error()\n\n       [1.0, 2.0, 3.0]\n       |&gt; maths.variance(ddof)\n       |&gt; should.equal(Ok(1.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.variance\ngleam_community/maths variance","url":"gleam_community/maths.html#variance"},{"doc":"gleam_community/maths","title":"weighted_product","content":"pub fn weighted_product(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted product of the elements in a list:\n\n \\\\[\n \\prod_{i=1}^n x_i^{w_i}\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the list and \\\\(x_i \\in \\mathbb{R}\\\\) is\n the value in the input list indexed by \\\\(i\\\\), while the \\\\(w_i \\in \\mathbb{R}\\\\)\n are corresponding positive weights.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/float\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.weighted_product()\n       |&gt; should.equal(Ok(1.0))\n\n       [#(1.0, 1.0), #(2.0, 1.0), #(3.0, 1.0)]\n       |&gt; maths.weighted_product()\n       |&gt; should.equal(Ok(6.0))\n\n       let assert Ok(tolerance) = float.power(10.0, -6.0)\n       let assert Ok(result) =\n         [#(9.0, 0.5), #(10.0, 0.5), #(10.0, 0.5)]\n         |&gt; maths.weighted_product()\n       result\n       |&gt; maths.is_close(30.0, 0.0, tolerance)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.weighted_product\ngleam_community/maths weighted_product","url":"gleam_community/maths.html#weighted_product"},{"doc":"gleam_community/maths","title":"weighted_sum","content":"pub fn weighted_sum(\n  arr: List(#(Float, Float)),\n) -&gt; Result(Float, Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the weighted sum of the elements in a list:\n\n \\\\[\n \\sum_{i=1}^n w_i x_i\n \\\\]\n\n In the formula, \\\\(n\\\\) is the length of the list and \\\\(x_i \\in \\mathbb{R}\\\\)\n is the value in the input list indexed by \\\\(i\\\\), while the \\\\(w_i \\in \\mathbb{R}\\\\)\n are corresponding positive weights.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/float\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       []\n       |&gt; maths.weighted_sum()\n       |&gt; should.equal(Ok(0.0))\n\n       [#(1.0, 1.0), #(2.0, 1.0), #(3.0, 1.0)]\n       |&gt; maths.weighted_sum()\n       |&gt; should.equal(Ok(6.0))\n\n       [#(9.0, 0.5), #(10.0, 0.5), #(10.0, 0.5)]\n       |&gt; maths.weighted_sum()\n       |&gt; should.equal(Ok(14.5))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.weighted_sum\ngleam_community/maths weighted_sum","url":"gleam_community/maths.html#weighted_sum"},{"doc":"gleam_community/maths","title":"yield_geometric_space","content":"pub fn yield_geometric_space(\n  start: Float,\n  stop: Float,\n  steps: Int,\n  endpoint: Bool,\n) -&gt; Result(Yielder(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function is similar to [`geometric_space`](#geometric_space) but instead returns a yielder\n (lazily evaluated sequence of elements). This function can be used whenever there is a need\n to generate a larger-than-usual sequence of elements.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder.{Next, Done}\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let assert Ok(logspace) = maths.yield_geometric_space(10.0, 1000.0, 3, True)\n\n       let assert Next(element, rest) = yielder.step(logspace)\n       should.equal(element, 10.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 100.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 1000.0)\n\n       // We have generated 3 values, so the 4th will be &#39;Done&#39;\n       should.equal(yielder.step(rest), Done)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.yield_geometric_space\ngleam_community/maths yield_geometric_space","url":"gleam_community/maths.html#yield_geometric_space"},{"doc":"gleam_community/maths","title":"yield_linear_space","content":"pub fn yield_linear_space(\n  start: Float,\n  stop: Float,\n  steps: Int,\n  endpoint: Bool,\n) -&gt; Result(Yielder(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function is similar to [`linear_space`](#linear_space) but instead returns a yielder\n (lazily evaluated sequence of elements). This function can be used whenever there is a need\n to generate a larger-than-usual sequence of elements.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder.{Next, Done}\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let assert Ok(linspace) = maths.yield_linear_space(10.0, 20.0, 5, True)\n\n       let assert Next(element, rest) = yielder.step(linspace)\n       should.equal(element, 10.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 12.5)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 15.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 17.5)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 20.0)\n\n       // We have generated 5 values, so the 6th will be &#39;Done&#39;\n       should.equal(yielder.step(rest), Done)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.yield_linear_space\ngleam_community/maths yield_linear_space","url":"gleam_community/maths.html#yield_linear_space"},{"doc":"gleam_community/maths","title":"yield_logarithmic_space","content":"pub fn yield_logarithmic_space(\n  start: Float,\n  stop: Float,\n  steps: Int,\n  endpoint: Bool,\n  base: Float,\n) -&gt; Result(Yielder(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function is similar to [`logarithmic_space`](#logarithmic_space) but instead returns a yielder\n (lazily evaluated sequence of elements). This function can be used whenever there is a need\n to generate a larger-than-usual sequence of elements.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder.{Next, Done}\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let assert Ok(logspace) =\n         maths.yield_logarithmic_space(1.0, 3.0, 3, True, 10.0)\n\n       let assert Next(element, rest) = yielder.step(logspace)\n       should.equal(element, 10.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 100.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 1000.0)\n\n       // We have generated 3 values, so the 4th will be &#39;Done&#39;\n       should.equal(yielder.step(rest), Done)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.yield_logarithmic_space\ngleam_community/maths yield_logarithmic_space","url":"gleam_community/maths.html#yield_logarithmic_space"},{"doc":"gleam_community/maths","title":"yield_step_range","content":"pub fn yield_step_range(\n  start: Float,\n  stop: Float,\n  increment: Float,\n) -&gt; Yielder(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function is similar to [`step_range`](#step_range) but instead returns a yielder\n (lazily evaluated sequence of elements). This function can be used whenever there is a need\n to generate a larger-than-usual sequence of elements.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder.{Next, Done}\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       let range = maths.yield_step_range(1.0, 2.5, 0.5)\n\n       let assert Next(element, rest) = yielder.step(range)\n       should.equal(element, 1.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 1.5)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 2.0)\n\n       // We have generated 3 values over the interval [1.0, 2.5)\n       // in increments of 0.5, so the 4th will be &#39;Done&#39;\n       should.equal(yielder.step(rest), Done)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.yield_step_range\ngleam_community/maths yield_step_range","url":"gleam_community/maths.html#yield_step_range"},{"doc":"gleam_community/maths","title":"yield_symmetric_space","content":"pub fn yield_symmetric_space(\n  center: Float,\n  radius: Float,\n  steps: Int,\n) -&gt; Result(Yielder(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function is similar to [`symmetric_space`](#symmetric_space) but instead returns a yielder\n (lazily evaluated sequence of elements). This function can be used whenever there is a need\n to generate a larger-than-usual sequence of elements.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleam/yielder.{Next, Done}\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example() {\n       let assert Ok(symspace) = maths.yield_symmetric_space(0.0, 5.0, 5)\n\n       let assert Next(element, rest) = yielder.step(symspace)\n       should.equal(element, -5.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, -2.5)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 0.0)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 2.5)\n\n       let assert Next(element, rest) = yielder.step(rest)\n       should.equal(element, 5.0)\n\n       // We have generated 5 values, so the 6th will be &#39;Done&#39;\n       should.equal(yielder.step(rest), Done)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.yield_symmetric_space\ngleam_community/maths yield_symmetric_space","url":"gleam_community/maths.html#yield_symmetric_space"},{"doc":"gleam_community/maths","title":"zscore","content":"pub fn zscore(\n  arr: List(Float),\n  ddof: Int,\n) -&gt; Result(List(Float), Nil)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculate the z-score of each value in the list relative to the sample\n mean and standard deviation.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       // Use degrees of freedom = 1\n       |&gt; maths.zscore(1)\n       |&gt; should.be_error()\n\n       [1.0, 2.0, 3.0]\n       // Use degrees of freedom = 1\n       |&gt; maths.zscore(1)\n       |&gt; should.equal(Ok([-1.0, 0.0, 1.0]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths.zscore\ngleam_community/maths zscore","url":"gleam_community/maths.html#zscore"},{"doc":"gleam_community/maths","title":"gleam_community/maths","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.11/dist/katex.min.css&quot; integrity=&quot;sha384-nB0miv6/jRmo5UMMR1wu3Gz6NLsoTkbqJghGIsx//Rlm+ZU03BU6SQNC66uf4l5+&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.11/dist/katex.min.js&quot; integrity=&quot;sha384-7zkQWkzuo3B5mTepMUcHkMB5jZaolc2xDwL6VFqjFALcbeS9Ggm/Yr2r3Dy4lfFg&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.11/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-43gviWU0YVjaDtb/GhzOouOXtZMP/7XUzwPTstBeZFe/+rCMvRwr4yROQP43s0Xk&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n              {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n              {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : true\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.10em; }\n&lt;/style&gt;\n","url":"gleam_community/maths.html"}]);